/* -------------------------------------------------------------------------------------------------
 *  CSS Parser
/* -------------------------------------------------------------------------------------------------
 *  Author: Nick Bradbury 
 *	Date: September 1998
 *  Copyright (c) 1997-2002 Macromedia, Inc. All Rights Reserved. Consult Software License Agreement for more details.
 *  Use of this script in non-Allaire products is strictly prohibited.
------------------------------------------------------------------------------------------------- */

#define css_DEFAULT          0
#define css_STRING			 1
#define css_STRING2			 2
#define css_NUMBER			 3
#define css_PUNCTUATION		 4

#define css_COMMENT			10
#define css_SELECTOR		11
#define css_PROPERTY		13
#define css_VALUE			14
#define css_OPENBRACKET		15
#define css_CLOSEBRACKET	16
#define	css_COLON			17
#define css_SEMICOLON		18
#define css_COMMENT_STAR	19
#define	css_PERIOD			20
#define css_HEXNUMBER		21

#define ss_IN_CSS_SELECTOR	50
#define ss_IN_CSS_PROPERTY  52
#define ss_IN_CSS_VALUE		53

  
#define _all_chars_                 '[\x00-\xFF]'
#define _dont_care_                 _all_chars_
#define _DEFAULT_BACKGROUND         clWhite
#define _DEFAULT_FOREGROUND         clBlack


%%language
Name                    = 'Cascading Style Sheets'
Case                    = __INSENSITIVE
Anchor			= [css_COMMENT css_SELECTOR]
StartState		= ss_IN_CSS_SELECTOR
ExampleText             =   '/* Comment */\n\
                             \H2, .head2      {\n\
                             \            font-family : \'Sans-Serif\';\n\
                             \            font-weight : bold;\n\
                             \            color : #339999;\n\
                             \      }\n'
 
 EditableStyles     
            ('Comments',	css_COMMENT),
            ('Selectors',	css_SELECTOR),
            ('Properties',	css_PROPERTY),
            ('Values',		css_VALUE),
            ('Punctuation',	css_PUNCTUATION),
            ('Numbers',		css_NUMBER),
            ('Strings',		css_STRING),
			('Default Text', css_DEFAULT)

%%words
'{'			_dont_care_			css_OPENBRACKET			
'}'			_dont_care_			css_CLOSEBRACKET		[ss_IN_CSS_PROPERTY ss_IN_CSS_VALUE]
'.'			_dont_care_			css_PERIOD				[ss_IN_CSS_SELECTOR]
':'			_dont_care_			css_COLON				[ss_IN_CSS_PROPERTY]
';'			_dont_care_			css_SEMICOLON			[ss_IN_CSS_VALUE]
'\/*'       _dont_care_       	css_COMMENT_STAR
'#'			_dont_care_			css_HEXNUMBER			[ss_IN_CSS_VALUE]

%%handler
css_COMMENT_STAR      _all_chars_?              '*\/'   		_use_
css_HEXNUMBER        '[0-9A-Fa-f]'             	'[^0-9a-fA-F]' 		_discard_
   
%%tokens

InState ss_IN_CSS_SELECTOR
 (
   css_SELECTOR          __STD_IDENTIFIER   [ss_IN_CSS_SELECTOR]
 )

InState ss_IN_CSS_PROPERTY
 (
   css_PROPERTY           __STD_IDENTIFIER   [ss_IN_CSS_PROPERTY]
 )

InState ss_IN_CSS_VALUE
 (
   css_VALUE             __STD_IDENTIFIER   	[ss_IN_CSS_VALUE]   
   css_STRING            __STD_HTML_STRING		[ss_IN_CSS_VALUE]
   css_STRING2           __STD_PASCALSTRING		[ss_IN_CSS_VALUE]
   css_NUMBER            __STD_NUMBER_OR_FP		[ss_IN_CSS_VALUE]
 )
 
%%effects
css_DEFAULT			[]	 		_DEFAULT_FOREGROUND		_DEFAULT_BACKGROUND
css_SELECTOR		[]	 		clPurple				_DEFAULT_BACKGROUND*
css_COMMENT			[]	 		clGray					_DEFAULT_BACKGROUND*
css_PROPERTY		[]	 		clBlue					_DEFAULT_BACKGROUND*
css_VALUE			[]  	 	clRed					_DEFAULT_BACKGROUND*
css_PUNCTUATION		[fsBold] 	clNavy					_DEFAULT_BACKGROUND*
css_NUMBER			[]			clMaroon				_DEFAULT_BACKGROUND*
css_STRING			[fsItalic]	_DEFAULT_FOREGROUND*    _DEFAULT_BACKGROUND*


%%map
css_DEFAULT			css_DEFAULT
css_COMMENT			css_COMMENT
css_COMMENT_STAR	css_COMMENT
css_SELECTOR		css_SELECTOR
css_PROPERTY		css_PROPERTY
css_VALUE			css_VALUE
css_NUMBER			css_NUMBER
css_HEXNUMBER	    css_NUMBER
css_STRING			css_STRING
css_STRING2			css_STRING
css_OPENBRACKET	    css_PUNCTUATION
css_CLOSEBRACKET	css_PUNCTUATION
css_PERIOD			css_PUNCTUATION
css_COLON			css_PUNCTUATION
css_SEMICOLON		css_PUNCTUATION

%%states
css_OPENBRACKET		(+[ss_IN_CSS_PROPERTY] 	-[ss_IN_CSS_VALUE ss_IN_CSS_SELECTOR])
css_CLOSEBRACKET	(+[ss_IN_CSS_SELECTOR] 	-[ss_IN_CSS_PROPERTY ss_IN_CSS_VALUE])
css_COLON			(+[ss_IN_CSS_VALUE] 	-[ss_IN_CSS_PROPERTY ss_IN_CSS_SELECTOR])
css_SEMICOLON		(+[ss_IN_CSS_PROPERTY] 	-[ss_IN_CSS_VALUE ss_IN_CSS_SELECTOR])
