/*
 * TSyntaxMemoParser Script
 * ------------------------
 *
 * Author  :          Ray Dise
 * Date    :          August 1, 2001
 * Last Modified:     October 15, 2001
 * Language:          C# (C sharp)
 * Note:              Based on information found in the
 *                    C# Programmers Reference in the .NET Framework
 *                    SDK Beta 2.
 */

// Elements
#define DEFAULT                0
#define CSHARP_KEYWORD         1
#define CSHARP_OPERATOR        2
#define CSHARP_DIRECTIVE       3
#define CSHARP_COMMENT         4
#define CSHARP_COMMENT_STAR    5
#define CSHARP_COMMENT_LINE    6
#define CSHARP_DOC_LINE        7
#define CSHARP_STRING          8
#define CSHARP_CHAR            9
#define CSHARP_IDENTIFIER      10
#define CSHARP_MISC            11
#define CSHARP_HEXNUMBER       12
#define CSHARP_NUMBER          13

// States
#define IN_DEFAULT          0

// Common Expressions
#define _ALPHA              '[_A-Za-z0-9]'
#define _NOT_ALPHA          '[^_A-Za-z0-9]'
#define _ALL_CHARS          '[\x00-\xFF]'
#define _DONT_CARE          _ALL_CHARS

#define DEFAULT_BACKGROUND	clWhite
#define DEFAULT_FOREGROUND	clBlack

%%language
Name            =   'C#'
Case            =   __SENSITIVE
Options         =   __DEFAULT_OPTIONS
WordWrapColumn  =   _EDGE
Gutter          =   _DEFAULT_GUTTER
Anchor          =   _DEFAULT_START_ANCHOR
EditableStyles  =   ('Default Text'         , DEFAULT),
                    ('Reserved Words'       , CSHARP_KEYWORD),
                    ('Directives'           , CSHARP_DIRECTIVE),
                    ('Operators'            , CSHARP_OPERATOR),
                    ('Comments'             , CSHARP_COMMENT),
                    ('Identifier'           , CSHARP_IDENTIFIER),
                    ('Miscellaneous'        , CSHARP_MISC),
                    ('Number'               , CSHARP_NUMBER),
                    ('String'               , CSHARP_STRING),
					('Documentation'        , CSHARP_DOC_LINE)

ExampleText               = '/* C# syntax highlighting */\n\
							\#define DEBUG\n\
							\using System;\n\
							\// my first C# program\n\
							\/// documentation text for class HelloWorld \n\
                            \public class HelloWorld\n\
							\{\n\
                            \  public static void main(String argv[]) {\n\
                            \    System.out.println("Hello World!");\n\
							\    a >> 2 > 3 ? 4 ? 5;\n\
                            \  }\n\
                            \}\n'

%%words
'abstract'              _NOT_ALPHA               CSHARP_KEYWORD
'as'                    _NOT_ALPHA               CSHARP_KEYWORD
'base'                  _NOT_ALPHA               CSHARP_KEYWORD
'bool'                  _NOT_ALPHA               CSHARP_KEYWORD
'break'                 _NOT_ALPHA               CSHARP_KEYWORD
'byte'                  _NOT_ALPHA               CSHARP_KEYWORD
'case'                  _NOT_ALPHA               CSHARP_KEYWORD
'catch'                 _NOT_ALPHA               CSHARP_KEYWORD
'char'                  _NOT_ALPHA               CSHARP_KEYWORD
'checked'               _NOT_ALPHA               CSHARP_KEYWORD
'class'                 _NOT_ALPHA               CSHARP_KEYWORD
'const'                 _NOT_ALPHA               CSHARP_KEYWORD
'continue'              _NOT_ALPHA               CSHARP_KEYWORD
'decimal'               _NOT_ALPHA               CSHARP_KEYWORD
'default'               _NOT_ALPHA               CSHARP_KEYWORD
'delegate'              _NOT_ALPHA               CSHARP_KEYWORD
'do'                    _NOT_ALPHA               CSHARP_KEYWORD
'double'                _NOT_ALPHA               CSHARP_KEYWORD
'else'                  _NOT_ALPHA               CSHARP_KEYWORD
'enum'                  _NOT_ALPHA               CSHARP_KEYWORD
'event'                 _NOT_ALPHA               CSHARP_KEYWORD
'explicit'              _NOT_ALPHA               CSHARP_KEYWORD
'extern'                _NOT_ALPHA               CSHARP_KEYWORD
'false'                 _NOT_ALPHA               CSHARP_KEYWORD
'finally'               _NOT_ALPHA               CSHARP_KEYWORD
'fixed'                 _NOT_ALPHA               CSHARP_KEYWORD
'float'                 _NOT_ALPHA               CSHARP_KEYWORD
'for'                   _NOT_ALPHA               CSHARP_KEYWORD
'foreach'               _NOT_ALPHA               CSHARP_KEYWORD
'get'                   _NOT_ALPHA               CSHARP_KEYWORD
'goto'                  _NOT_ALPHA               CSHARP_KEYWORD
'if'                    _NOT_ALPHA               CSHARP_KEYWORD
'implicit'              _NOT_ALPHA               CSHARP_KEYWORD
'in'                    _NOT_ALPHA               CSHARP_KEYWORD
'int'                   _NOT_ALPHA               CSHARP_KEYWORD
'interface'             _NOT_ALPHA               CSHARP_KEYWORD
'internal'              _NOT_ALPHA               CSHARP_KEYWORD
'is'                    _NOT_ALPHA               CSHARP_KEYWORD
'lock'                  _NOT_ALPHA               CSHARP_KEYWORD
'long'                  _NOT_ALPHA               CSHARP_KEYWORD
'namespace'             _NOT_ALPHA               CSHARP_KEYWORD
'new'                   _NOT_ALPHA               CSHARP_KEYWORD
'null'                  _NOT_ALPHA               CSHARP_KEYWORD
'object'                _NOT_ALPHA               CSHARP_KEYWORD
'operator'              _NOT_ALPHA               CSHARP_KEYWORD
'out'                   _NOT_ALPHA               CSHARP_KEYWORD
'override'              _NOT_ALPHA               CSHARP_KEYWORD
'params'                _NOT_ALPHA               CSHARP_KEYWORD
'private'               _NOT_ALPHA               CSHARP_KEYWORD
'protected'             _NOT_ALPHA               CSHARP_KEYWORD
'public'                _NOT_ALPHA               CSHARP_KEYWORD
'readonly'              _NOT_ALPHA               CSHARP_KEYWORD
'ref'                   _NOT_ALPHA               CSHARP_KEYWORD
'return'                _NOT_ALPHA               CSHARP_KEYWORD
'sbyte'                 _NOT_ALPHA               CSHARP_KEYWORD
'sealed'                _NOT_ALPHA               CSHARP_KEYWORD
'set'                   _NOT_ALPHA               CSHARP_KEYWORD
'short'                 _NOT_ALPHA               CSHARP_KEYWORD
'sizeof'                _NOT_ALPHA               CSHARP_KEYWORD
'stackalloc'            _NOT_ALPHA               CSHARP_KEYWORD
'static'                _NOT_ALPHA               CSHARP_KEYWORD
'string'                _NOT_ALPHA               CSHARP_KEYWORD
'struct'                _NOT_ALPHA               CSHARP_KEYWORD
'switch'                _NOT_ALPHA               CSHARP_KEYWORD
'this'                  _NOT_ALPHA               CSHARP_KEYWORD
'throw'                 _NOT_ALPHA               CSHARP_KEYWORD
'true'                  _NOT_ALPHA               CSHARP_KEYWORD
'try'                   _NOT_ALPHA               CSHARP_KEYWORD
'typeof'                _NOT_ALPHA               CSHARP_KEYWORD
'unsafe'                _NOT_ALPHA               CSHARP_KEYWORD
'ushort'                _NOT_ALPHA               CSHARP_KEYWORD
'using'                 _NOT_ALPHA               CSHARP_KEYWORD
'uint'                  _NOT_ALPHA               CSHARP_KEYWORD
'ulong'                 _NOT_ALPHA               CSHARP_KEYWORD
'unchecked'             _NOT_ALPHA               CSHARP_KEYWORD
'virtual'               _NOT_ALPHA               CSHARP_KEYWORD
'void'                  _NOT_ALPHA               CSHARP_KEYWORD
'while'                 _NOT_ALPHA               CSHARP_KEYWORD
'++'                    _DONT_CARE               CSHARP_OPERATOR
'--'                    _DONT_CARE               CSHARP_OPERATOR
'+'                     _DONT_CARE               CSHARP_OPERATOR
'-'                     _DONT_CARE               CSHARP_OPERATOR
'*'                     _DONT_CARE               CSHARP_OPERATOR
'/'                     _DONT_CARE               CSHARP_OPERATOR
'&'                     _DONT_CARE               CSHARP_OPERATOR
'!'                     _DONT_CARE               CSHARP_OPERATOR
'~'                     _DONT_CARE               CSHARP_OPERATOR
'%'                     _DONT_CARE               CSHARP_OPERATOR
'>'                     _DONT_CARE               CSHARP_OPERATOR
'<'                     _DONT_CARE               CSHARP_OPERATOR
'>>'                    _DONT_CARE               CSHARP_OPERATOR
'<<'                    _DONT_CARE               CSHARP_OPERATOR
'>='                    _DONT_CARE               CSHARP_OPERATOR
'<='                    _DONT_CARE               CSHARP_OPERATOR
'=='                    _DONT_CARE               CSHARP_OPERATOR
'='                     _DONT_CARE               CSHARP_OPERATOR
'!='                    _DONT_CARE               CSHARP_OPERATOR
'^'                     _DONT_CARE               CSHARP_OPERATOR
'|'                     _DONT_CARE               CSHARP_OPERATOR
'&&'                    _DONT_CARE               CSHARP_OPERATOR
'||'                    _DONT_CARE               CSHARP_OPERATOR
'?'                     _DONT_CARE               CSHARP_OPERATOR
':'                     _DONT_CARE               CSHARP_OPERATOR
'+='                    _DONT_CARE               CSHARP_OPERATOR
'-='                    _DONT_CARE               CSHARP_OPERATOR
'*='                    _DONT_CARE               CSHARP_OPERATOR
'/='                    _DONT_CARE               CSHARP_OPERATOR
'%='                    _DONT_CARE               CSHARP_OPERATOR
'>>='                   _DONT_CARE               CSHARP_OPERATOR
'<<='                   _DONT_CARE               CSHARP_OPERATOR
'&='                    _DONT_CARE               CSHARP_OPERATOR
'^='                    _DONT_CARE               CSHARP_OPERATOR
'|='                    _DONT_CARE               CSHARP_OPERATOR
';'                     _DONT_CARE               CSHARP_MISC
'('                     _DONT_CARE               CSHARP_MISC
')'                     _DONT_CARE               CSHARP_MISC
'['                     _DONT_CARE               CSHARP_MISC
']'                     _DONT_CARE               CSHARP_MISC
'{'                     _DONT_CARE               CSHARP_MISC
'}'                     _DONT_CARE               CSHARP_MISC
'#if'                   _DONT_CARE               CSHARP_DIRECTIVE
'#else'                 _DONT_CARE               CSHARP_DIRECTIVE 
'#elif'                 _DONT_CARE               CSHARP_DIRECTIVE
'#endif'                _DONT_CARE               CSHARP_DIRECTIVE
'#define'               _DONT_CARE               CSHARP_DIRECTIVE
'#undef'                _DONT_CARE               CSHARP_DIRECTIVE
'#warning'              _DONT_CARE               CSHARP_DIRECTIVE
'#error'                _DONT_CARE               CSHARP_DIRECTIVE
'#line'                 _DONT_CARE               CSHARP_DIRECTIVE
'#region'               _DONT_CARE               CSHARP_DIRECTIVE
'#endregion'            _DONT_CARE               CSHARP_DIRECTIVE
'\/*'                   _DONT_CARE               CSHARP_COMMENT_STAR
'\/\/'                  _DONT_CARE               CSHARP_COMMENT_LINE
'\/\/\/'                _DONT_CARE               CSHARP_DOC_LINE
//'"'                   _DONT_CARE               CSHARP_STRING
//'\''                  _DONT_CARE               CSHARP_CHAR
'0'                    '[xX]'                    CSHARP_HEXNUMBER

%%handlers
CSHARP_COMMENT_LINE         '[^\n]'?                    '\n'           _discard_
CSHARP_COMMENT_STAR         _all_chars?                 '*\/'          _use_
CSHARP_DOC_LINE             '[^\n]'?                    '\n'           _discard_
CSHARP_HEXNUMBER            '[xX0-9A-Fa-f]'             '[^0-9a-fA-F]' _discard_

%%tokens
CSHARP_STRING               __STD_C_STRING
CSHARP_CHAR                 __STD_C_CHAR
CSHARP_IDENTIFIER           '[a-zA-Z_]'  '[a-zA-Z0-9_\.]'?  '[^a-zA-Z0-9_\.]' _discard_ //__STD_IDENTIFIER
CSHARP_NUMBER               __STD_NUMBER_OR_FP

%%effects
DEFAULT           []             DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
CSHARP_KEYWORD    [fsBold]       clBlue                  DEFAULT_BACKGROUND*
CSHARP_MISC       []             DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
CSHARP_OPERATOR   []             DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
CSHARP_DIRECTIVE  []             clGreen                 DEFAULT_BACKGROUND*
CSHARP_COMMENT    [fsItalic]     clGreen                 DEFAULT_BACKGROUND*
CSHARP_DOC_LINE   [fsItalic]     clPurple                DEFAULT_BACKGROUND*
CSHARP_STRING     [fsItalic]     DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
CSHARP_IDENTIFIER []             DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
CSHARP_NUMBER     []             clRed                   DEFAULT_BACKGROUND*

%%map
DEFAULT                DEFAULT
CSHARP_KEYWORD         CSHARP_KEYWORD
CSHARP_OPERATOR        CSHARP_OPERATOR
CSHARP_DIRECTIVE       CSHARP_DIRECTIVE
CSHARP_COMMENT         CSHARP_COMMENT
CSHARP_COMMENT_LINE    CSHARP_COMMENT
CSHARP_COMMENT_STAR    CSHARP_COMMENT
CSHARP_DOC_LINE        CSHARP_DOC_LINE
CSHARP_STRING          CSHARP_STRING
CSHARP_CHAR            CSHARP_STRING
CSHARP_IDENTIFIER      CSHARP_IDENTIFIER
CSHARP_MISC            CSHARP_MISC
CSHARP_NUMBER          CSHARP_NUMBER
CSHARP_HEXNUMBER       CSHARP_NUMBER

