/* -------------------------------------------------------------------------------------------------
 *  Perl Parser
/* -------------------------------------------------------------------------------------------------
 *  Author: Nick Bradbury 
 *	Date: September 1998
 *  Copyright (c) 1997-2002 Macromedia, Inc. All Rights Reserved. Consult Software License Agreement for more details.
 *  Use of this script in non-Allaire products is strictly prohibited.
 *  10/28/00 - BCJ - Added 'Script Tag' editable style
------------------------------------------------------------------------------------------------- */

#define pl_DEFAULT              0 
#define pl_COMMENT              2
#define pl_COMMENT_LINE         3
#define pl_STRING               4
#define pl_STRING2				5
#define pl_NUMBER               7
#define pl_WHITESPACE			8
#define pl_IDENTIFIER			9

#define pl_SCRIPT_TAG			20
#define pl_KEYWORD				21
#define pl_STATEMENT			22
#define pl_PUNCTUATION			23

#define _non_alpha_                 '[^_A-Za-z0-9]'
#define _all_chars_                 '[\x01-\xFF]'
#define _no_chars_                  '[]'
#define _dont_care_                 _all_chars_
#define _DEFAULT_BACKGROUND         clWhite
#define _DEFAULT_FOREGROUND         clBlack

%%language
Name                      = 'Perl'
Case                      = __SENSITIVE
Anchor                    = _DEFAULT_START_ANCHOR
ExampleText               = '\# Perl syntax highlighting\n\
                            \var worldString="Hello, world"\n\
                            \document.write(worldString.small())\n\
                            \document.write("<P>" + worldString.big())\n\
                            \document.write("<P>" + worldString.fontsize(7))\n'

ExampleText               = 	'\{   package newgetopt;\n\
    				 \# Perl syntax highlighting\n\
				 \$REQUIRE_ORDER = 0;\n\
    				 \if ( defined $ENV{"POSIXLY_CORRECT"} )\n'
                            
EditableStyles              ('Keyword',       pl_KEYWORD),
			    ('Statement',     pl_STATEMENT),			
                            ('Comment',       pl_COMMENT),
                            ('String',        pl_STRING),
                            ('Number',        pl_NUMBER),                            
                            ('Default',       pl_DEFAULT),
							('Script Tag',		pl_SCRIPT_TAG)

%%words
'<script'		    	_dont_care_       	pl_SCRIPT_TAG
'</script'		    	_dont_care_       	pl_SCRIPT_TAG
'<SCRIP'		    	_dont_care_       	pl_SCRIPT_TAG
'</SCRIP'		    	_dont_care_       	pl_SCRIPT_TAG
/////////////////////////////////////////////////////////////////////////
// Statements
/////////////////////////////////////////////////////////////////////////
'continue'			_non_alpha_		pl_STATEMENT
'do'				_non_alpha_		pl_STATEMENT
'else'				_non_alpha_		pl_STATEMENT
'elsif'				_non_alpha_		pl_STATEMENT
'for'				_non_alpha_		pl_STATEMENT
'foreach'			_non_alpha_		pl_STATEMENT
'goto'				_non_alpha_		pl_STATEMENT
'if'				_non_alpha_		pl_STATEMENT
'last'				_non_alpha_		pl_STATEMENT
'local'				_non_alpha_		pl_STATEMENT
'my'				_non_alpha_		pl_STATEMENT
'next'				_non_alpha_		pl_STATEMENT
'no'				_non_alpha_		pl_STATEMENT
'package'			_non_alpha_		pl_STATEMENT
'redo'				_non_alpha_		pl_STATEMENT
'return'			_non_alpha_		pl_STATEMENT
'require'			_non_alpha_		pl_STATEMENT
'sub'				_non_alpha_		pl_STATEMENT
'until'				_non_alpha_		pl_STATEMENT
'unless'			_non_alpha_		pl_STATEMENT
'use'				_non_alpha_		pl_STATEMENT
'while'				_non_alpha_		pl_STATEMENT
'{'					_non_alpha_		pl_PUNCTUATION
'}'					_non_alpha_		pl_PUNCTUATION
'$'					_dont_care_		pl_PUNCTUATION
'$#'				_dont_care_		pl_PUNCTUATION
'@'					_dont_care_		pl_PUNCTUATION
/////////////////////////////////////////////////////////////////////////
// Keywords
/////////////////////////////////////////////////////////////////////////
'accept'			_non_alpha_		pl_KEYWORD
'alarm'				_non_alpha_		pl_KEYWORD
'atan2'				_non_alpha_		pl_KEYWORD
'bind'				_non_alpha_		pl_KEYWORD
'binmode'			_non_alpha_		pl_KEYWORD
'bless'				_non_alpha_		pl_KEYWORD
'caller'			_non_alpha_		pl_KEYWORD
'chdir'				_non_alpha_		pl_KEYWORD
'chmod'				_non_alpha_		pl_KEYWORD
'chomp'				_non_alpha_		pl_KEYWORD
'chop'				_non_alpha_		pl_KEYWORD
'chown'				_non_alpha_		pl_KEYWORD
'chr'				_non_alpha_		pl_KEYWORD
'chroot'			_non_alpha_		pl_KEYWORD
'close'				_non_alpha_		pl_KEYWORD
'closedir'			_non_alpha_		pl_KEYWORD
'connect'			_non_alpha_		pl_KEYWORD
'cos'				_non_alpha_		pl_KEYWORD
'crypt'				_non_alpha_		pl_KEYWORD
'dbmclose'			_non_alpha_		pl_KEYWORD
'dbmopen'			_non_alpha_		pl_KEYWORD
'defined'			_non_alpha_		pl_KEYWORD
'delete'			_non_alpha_		pl_KEYWORD
'die'				_non_alpha_		pl_KEYWORD
'dump'				_non_alpha_		pl_KEYWORD
'each'				_non_alpha_		pl_KEYWORD
'endgrent'			_non_alpha_		pl_KEYWORD
'endhostent'			_non_alpha_		pl_KEYWORD
'endnetent'			_non_alpha_		pl_KEYWORD
'endprotoent'			_non_alpha_		pl_KEYWORD
'endpwent'			_non_alpha_		pl_KEYWORD
'endservent'			_non_alpha_		pl_KEYWORD
'eof'				_non_alpha_		pl_KEYWORD
'eval'				_non_alpha_		pl_KEYWORD
'exec'				_non_alpha_		pl_KEYWORD
'exit'				_non_alpha_		pl_KEYWORD
'exp'				_non_alpha_		pl_KEYWORD
'fcntl'				_non_alpha_		pl_KEYWORD
'fileno'			_non_alpha_		pl_KEYWORD
'flock'				_non_alpha_		pl_KEYWORD
'fork'				_non_alpha_		pl_KEYWORD
'formline'			_non_alpha_		pl_KEYWORD
'getc'				_non_alpha_		pl_KEYWORD
'getgrent'			_non_alpha_		pl_KEYWORD
'getgrgid'			_non_alpha_		pl_KEYWORD
'getgrname'			_non_alpha_		pl_KEYWORD
'gethostbyaddr'			_non_alpha_		pl_KEYWORD
'gethostbyname'			_non_alpha_		pl_KEYWORD
'gethostent'			_non_alpha_		pl_KEYWORD
'getlogin'			_non_alpha_		pl_KEYWORD
'getnetbyaddr'			_non_alpha_		pl_KEYWORD
'getnetbyname'			_non_alpha_		pl_KEYWORD
'getnetent'			_non_alpha_		pl_KEYWORD
'getpeername'			_non_alpha_		pl_KEYWORD
'getpgrp'			_non_alpha_		pl_KEYWORD
'getppid'			_non_alpha_		pl_KEYWORD
'getpriority'			_non_alpha_		pl_KEYWORD
'getprotobyname'		_non_alpha_		pl_KEYWORD
'getprotobynumber'		_non_alpha_		pl_KEYWORD
'getprotoent'			_non_alpha_		pl_KEYWORD
'getpwent'			_non_alpha_		pl_KEYWORD
'getpwnam'			_non_alpha_		pl_KEYWORD
'getpwuid'			_non_alpha_		pl_KEYWORD
'getservbyname'			_non_alpha_		pl_KEYWORD
'getservbyport'			_non_alpha_		pl_KEYWORD
'getservent'			_non_alpha_		pl_KEYWORD
'getsockname'			_non_alpha_		pl_KEYWORD
'getsockopt'			_non_alpha_		pl_KEYWORD
'glob'				_non_alpha_		pl_KEYWORD
'gmtime'			_non_alpha_		pl_KEYWORD
'grep'				_non_alpha_		pl_KEYWORD
'hex'				_non_alpha_		pl_KEYWORD
'index'				_non_alpha_		pl_KEYWORD
'int'				_non_alpha_		pl_KEYWORD
'ioctl'				_non_alpha_		pl_KEYWORD
'join'				_non_alpha_		pl_KEYWORD
'keys'				_non_alpha_		pl_KEYWORD
'kill'				_non_alpha_		pl_KEYWORD
'lc'				_non_alpha_		pl_KEYWORD
'lcfirst'			_non_alpha_		pl_KEYWORD
'length'			_non_alpha_		pl_KEYWORD
'link'				_non_alpha_		pl_KEYWORD
'listen'			_non_alpha_		pl_KEYWORD
'localtime'			_non_alpha_		pl_KEYWORD
'log'				_non_alpha_		pl_KEYWORD
'lstat'				_non_alpha_		pl_KEYWORD
'map'				_non_alpha_		pl_KEYWORD
'mkdir'				_non_alpha_		pl_KEYWORD
'msgctl'			_non_alpha_		pl_KEYWORD
'msgget'			_non_alpha_		pl_KEYWORD
'msgrcv'			_non_alpha_		pl_KEYWORD
'msgsnd'			_non_alpha_		pl_KEYWORD
'oct'				_non_alpha_		pl_KEYWORD
'open'				_non_alpha_		pl_KEYWORD
'opendir'			_non_alpha_		pl_KEYWORD
'ord'				_non_alpha_		pl_KEYWORD
'pack'				_non_alpha_		pl_KEYWORD
'pipe'				_non_alpha_		pl_KEYWORD
'pop'				_non_alpha_		pl_KEYWORD
'pos'				_non_alpha_		pl_KEYWORD
'print'				_non_alpha_		pl_KEYWORD
'printf'			_non_alpha_		pl_KEYWORD
'push'				_non_alpha_		pl_KEYWORD
'quotemeta'			_non_alpha_		pl_KEYWORD
'rand'				_non_alpha_		pl_KEYWORD
'read'				_non_alpha_		pl_KEYWORD
'readdir'			_non_alpha_		pl_KEYWORD
'readline'			_non_alpha_		pl_KEYWORD
'readlink'			_non_alpha_		pl_KEYWORD
'recv'				_non_alpha_		pl_KEYWORD
'ref'				_non_alpha_		pl_KEYWORD
'rename'			_non_alpha_		pl_KEYWORD
'reset'				_non_alpha_		pl_KEYWORD
'reverse'			_non_alpha_		pl_KEYWORD
'rewindir'			_non_alpha_		pl_KEYWORD
'rindex'			_non_alpha_		pl_KEYWORD
'rmdir'				_non_alpha_		pl_KEYWORD
'scalar'			_non_alpha_		pl_KEYWORD
'seek'				_non_alpha_		pl_KEYWORD
'seekdir'			_non_alpha_		pl_KEYWORD
'select'			_non_alpha_		pl_KEYWORD
'semctl'			_non_alpha_		pl_KEYWORD
'semgett'			_non_alpha_		pl_KEYWORD
'semop'				_non_alpha_		pl_KEYWORD
'send'				_non_alpha_		pl_KEYWORD
'setgrent'			_non_alpha_		pl_KEYWORD
'sethostent'			_non_alpha_		pl_KEYWORD
'setnetent'			_non_alpha_		pl_KEYWORD
'setpgrp'			_non_alpha_		pl_KEYWORD
'setpriority'			_non_alpha_		pl_KEYWORD
'setprotoent'			_non_alpha_		pl_KEYWORD
'setpwent'			_non_alpha_		pl_KEYWORD
'setservent'			_non_alpha_		pl_KEYWORD
'setsockopt'			_non_alpha_		pl_KEYWORD
'shift'				_non_alpha_		pl_KEYWORD
'shmctl'			_non_alpha_		pl_KEYWORD
'shmget'			_non_alpha_		pl_KEYWORD
'shmread'			_non_alpha_		pl_KEYWORD
'shmwrite'			_non_alpha_		pl_KEYWORD
'shutdown'			_non_alpha_		pl_KEYWORD
'sin'				_non_alpha_		pl_KEYWORD
'sleep'				_non_alpha_		pl_KEYWORD
'socket'			_non_alpha_		pl_KEYWORD
'socketpair'			_non_alpha_		pl_KEYWORD
'sort'				_non_alpha_		pl_KEYWORD
'splice'			_non_alpha_		pl_KEYWORD
'split'				_non_alpha_		pl_KEYWORD
'sprintf'			_non_alpha_		pl_KEYWORD
'sqrt'				_non_alpha_		pl_KEYWORD
'srand'				_non_alpha_		pl_KEYWORD
'stat'				_non_alpha_		pl_KEYWORD
'study'				_non_alpha_		pl_KEYWORD
'substr'			_non_alpha_		pl_KEYWORD
'symlink'			_non_alpha_		pl_KEYWORD
'syscall'			_non_alpha_		pl_KEYWORD
'sysopen'			_non_alpha_		pl_KEYWORD
'sysread'			_non_alpha_		pl_KEYWORD
'system'			_non_alpha_		pl_KEYWORD
'syswrite'			_non_alpha_		pl_KEYWORD
'tell'				_non_alpha_		pl_KEYWORD
'telldir'			_non_alpha_		pl_KEYWORD
'tie'				_non_alpha_		pl_KEYWORD
'tied'				_non_alpha_		pl_KEYWORD
'time'				_non_alpha_		pl_KEYWORD
'times'				_non_alpha_		pl_KEYWORD
'truncate'			_non_alpha_		pl_KEYWORD
'uc'				_non_alpha_		pl_KEYWORD
'ucfirst'			_non_alpha_		pl_KEYWORD
'umask'				_non_alpha_		pl_KEYWORD
'undef'				_non_alpha_		pl_KEYWORD
'unlink'			_non_alpha_		pl_KEYWORD
'unpack'			_non_alpha_		pl_KEYWORD
'unshift'			_non_alpha_		pl_KEYWORD
'utime'				_non_alpha_		pl_KEYWORD
'values'			_non_alpha_		pl_KEYWORD
'vec'				_non_alpha_		pl_KEYWORD
'wait'				_non_alpha_		pl_KEYWORD
'waitpid'			_non_alpha_		pl_KEYWORD
'wantarray'			_non_alpha_		pl_KEYWORD
'warn'				_non_alpha_		pl_KEYWORD
'write'				_non_alpha_		pl_KEYWORD
'AUTOLOAD'			_non_alpha_		pl_KEYWORD
'BEGIN'				_non_alpha_		pl_KEYWORD
'CORE'				_non_alpha_		pl_KEYWORD
'DESTROY'			_non_alpha_		pl_KEYWORD
'eq '				_non_alpha_		pl_KEYWORD
'END '				_non_alpha_		pl_KEYWORD
'ge'				_non_alpha_		pl_KEYWORD
'gt '				_non_alpha_		pl_KEYWORD
'le'				_non_alpha_		pl_KEYWORD
'lt '				_non_alpha_		pl_KEYWORD
'ne'				_non_alpha_		pl_KEYWORD
'not '				_non_alpha_		pl_KEYWORD
'm '				_non_alpha_		pl_KEYWORD
'or'				_non_alpha_		pl_KEYWORD
'q'				    _non_alpha_		pl_KEYWORD
'qq'				_non_alpha_		pl_KEYWORD
'qw'				_non_alpha_		pl_KEYWORD
'qx '				_non_alpha_		pl_KEYWORD
'SUPER '			_non_alpha_		pl_KEYWORD
's '				_non_alpha_		pl_KEYWORD
'tr'				_non_alpha_		pl_KEYWORD
'UNIVERSAL'			_non_alpha_		pl_KEYWORD
'x'				    _non_alpha_		pl_KEYWORD
'xor'				_non_alpha_		pl_KEYWORD
'y'				    _non_alpha_		pl_KEYWORD
/////////////////////////////////////////////////////////////////////////
// Comments
/////////////////////////////////////////////////////////////////////////
'\#'                      	_dont_care_       	pl_COMMENT_LINE
/////////////////////////////////////////////////////////////////////////

%%handler
pl_COMMENT_LINE         '[^\n]'?                    '\n'           _discard_
pl_SCRIPT_TAG			_all_chars_?                '>'            _use_

%%tokens
pl_WHITESPACE           '[\x01-\s]'                 '[\x01-\s]'?       '[^\x01-\s]'     _discard_
pl_STRING               __STD_C_STRING
pl_STRING2           	__STD_PASCALSTRING	
pl_NUMBER               __STD_NUMBER_OR_FP
pl_IDENTIFIER			__STD_IDENTIFIER

%%effects
pl_DEFAULT              []              _DEFAULT_FOREGROUND		_DEFAULT_BACKGROUND
pl_STRING               []              _DEFAULT_FOREGROUND*	_DEFAULT_BACKGROUND*
pl_COMMENT              [fsItalic]      clGreen					_DEFAULT_BACKGROUND*
pl_NUMBER               []              clMaroon				_DEFAULT_BACKGROUND*
pl_SCRIPT_TAG			[]				clRed					_DEFAULT_BACKGROUND*
pl_STATEMENT			[fsBold]		clNavy					_DEFAULT_BACKGROUND*
pl_KEYWORD              []              clBlue	          		_DEFAULT_BACKGROUND*

%%map
pl_DEFAULT				pl_DEFAULT
pl_STRING               pl_STRING
pl_STRING2				pl_STRING
pl_COMMENT              pl_COMMENT
pl_COMMENT_LINE         pl_COMMENT
pl_STRING               pl_STRING
pl_NUMBER               pl_NUMBER
pl_SCRIPT_TAG			pl_SCRIPT_TAG
pl_STATEMENT			pl_STATEMENT
pl_KEYWORD				pl_KEYWORD
pl_PUNCTUATION			pl_STATEMENT
pl_WHITESPACE			pl_DEFAULT
pl_IDENTIFIER			pl_DEFAULT
