/*
 * SQL Parser
 * ------------------------ 
 * Author  :          David Brock, Modified by N.Bradbury 
 * Date    :          September 1998
 * Copyright (c) 1997-2002 Macromedia, Inc. All Rights Reserved. Consult Software License Agreement for more details.
 */
 
//--------------------------------------------------------------------------------------------------------------------

#define st_DEFAULT                  0
#define st_COMMENT                  1
#define st_IDENTIFIER               2
#define st_STRING                   3
#define st_NUMBER                   4
#define st_SYMBOL                   5
#define st_RESERVED                 6
#define st_COMMENT_LINE             7
#define st_COMMENT_STAR             8


#define _non_alpha_                 '[^_A-Za-z0-9]'
#define _all_chars_                 '[\x01-\xFF]'
#define _no_chars_                  '[]'
#define _dont_care_                 _all_chars_
#define _DEFAULT_BACKGROUND         clWhite
#define _DEFAULT_FOREGROUND         clBlack

%%language
Name                      = 'SQL'
Case                      = __INSENSITIVE
Options                   = __DEFAULT_OPTIONS
WordWrapColumn            = _EDGE
Anchor                    = _DEFAULT_START_ANCHOR
ExampleText               = '/* Sample SQL text */\n\
                            \select * from country\n\
                            \         where name like \'%UK%\'\n'
EditableStyles              ('Reserved word', st_RESERVED),
                            ('Comment',       st_COMMENT),
                            ('Identifier',    st_IDENTIFIER),
                            ('String',        st_STRING),
                            ('Number',        st_NUMBER),
                            ('Symbols',       st_SYMBOL),
                            ('Default',       st_DEFAULT)

%%words
'\/\/'           _dont_care_       st_COMMENT_LINE
'/*'             _dont_care_       st_COMMENT_STAR
'--'           	 _dont_care_       st_COMMENT_LINE // njb
'!'              _dont_care_       st_SYMBOL
'$'              _dont_care_       st_SYMBOL
'%'              _dont_care_       st_SYMBOL
'^'              _dont_care_       st_SYMBOL
'&'              _dont_care_       st_SYMBOL
'*'              _dont_care_       st_SYMBOL
'('              _dont_care_       st_SYMBOL
')'              _dont_care_       st_SYMBOL
'-'              _dont_care_       st_SYMBOL
'='              _dont_care_       st_SYMBOL
'+'              _dont_care_       st_SYMBOL
'{'              _dont_care_       st_SYMBOL
'}'              _dont_care_       st_SYMBOL
'['              _dont_care_       st_SYMBOL
']'              _dont_care_       st_SYMBOL
':'              _dont_care_       st_SYMBOL
';'              _dont_care_       st_SYMBOL
'@'              _dont_care_       st_SYMBOL
'#'              _dont_care_       st_SYMBOL
'~'              _dont_care_       st_SYMBOL
'<'              _dont_care_       st_SYMBOL
'>'              _dont_care_       st_SYMBOL
','              _dont_care_       st_SYMBOL
'.'              _dont_care_       st_SYMBOL
'/'              _dont_care_       st_SYMBOL
'?'              _dont_care_       st_SYMBOL
'\\'             _dont_care_       st_SYMBOL
'ACTIVE'         _non_alpha_       st_RESERVED
'ALL'            _non_alpha_       st_RESERVED
'AFTER'          _non_alpha_       st_RESERVED
'ALTER'          _non_alpha_       st_RESERVED
'AND'            _non_alpha_       st_RESERVED
'ANY'            _non_alpha_       st_RESERVED
'AS'             _non_alpha_       st_RESERVED
'ASC'            _non_alpha_       st_RESERVED
'ASCENDING'      _non_alpha_       st_RESERVED
'AT'             _non_alpha_       st_RESERVED
'AUTO'           _non_alpha_       st_RESERVED
'AUTOINC'        _non_alpha_       st_RESERVED
'BASE_NAME'      _non_alpha_       st_RESERVED
'BEFORE'         _non_alpha_       st_RESERVED
'BEGIN'          _non_alpha_       st_RESERVED
'BETWEEN'        _non_alpha_       st_RESERVED
'BOTH'           _non_alpha_       st_RESERVED
'BY'             _non_alpha_       st_RESERVED
'CACHE'          _non_alpha_       st_RESERVED
'CAST'           _non_alpha_       st_RESERVED
'CHECK'          _non_alpha_       st_RESERVED
'COLUMN'         _non_alpha_       st_RESERVED
'COMMIT'         _non_alpha_       st_RESERVED
'COMMITTED'      _non_alpha_       st_RESERVED
'COMPUTED'       _non_alpha_       st_RESERVED
'CONDITIONAL'    _non_alpha_       st_RESERVED
'CONNECT'        _non_alpha_       st_RESERVED
'CONSTRAINT'     _non_alpha_       st_RESERVED
'CONTAINING'     _non_alpha_       st_RESERVED
'COUNT'          _non_alpha_       st_RESERVED
'CREATE'         _non_alpha_       st_RESERVED
'CURRENT'        _non_alpha_       st_RESERVED
'CURSOR'         _non_alpha_       st_RESERVED
'DATABASE'       _non_alpha_       st_RESERVED
'DEBUG'          _non_alpha_       st_RESERVED
'DECLARE'        _non_alpha_       st_RESERVED
'DEFAULT'        _non_alpha_       st_RESERVED
'DELETE'         _non_alpha_       st_RESERVED
'DESC'           _non_alpha_       st_RESERVED
'DESCENDING'     _non_alpha_       st_RESERVED
'DISTINCT'       _non_alpha_       st_RESERVED
'DOMAIN'         _non_alpha_       st_RESERVED
'DO'             _non_alpha_       st_RESERVED
'DROP'           _non_alpha_       st_RESERVED
'ELSE'           _non_alpha_       st_RESERVED
'END'            _non_alpha_       st_RESERVED
'ENTRY_POINT'    _non_alpha_       st_RESERVED
'ESCAPE'         _non_alpha_       st_RESERVED
'EXCEPTION'      _non_alpha_       st_RESERVED
'EXECUTE'        _non_alpha_       st_RESERVED
'EXISTS'         _non_alpha_       st_RESERVED
'EXIT'           _non_alpha_       st_RESERVED
'EXTERNAL'       _non_alpha_       st_RESERVED
'EXTRACT'        _non_alpha_       st_RESERVED
'FILTER'         _non_alpha_       st_RESERVED
'FOR'            _non_alpha_       st_RESERVED
'FOREIGN'        _non_alpha_       st_RESERVED
'FROM'           _non_alpha_       st_RESERVED
'FULL'           _non_alpha_       st_RESERVED
'FUNCTION'       _non_alpha_       st_RESERVED
'GENERATOR'      _non_alpha_       st_RESERVED
'GRANT'          _non_alpha_       st_RESERVED
'GROUP'          _non_alpha_       st_RESERVED
'HAVING'         _non_alpha_       st_RESERVED
'IF'             _non_alpha_       st_RESERVED
'IN'             _non_alpha_       st_RESERVED
'INACTIVE'       _non_alpha_       st_RESERVED
'INDEX'          _non_alpha_       st_RESERVED
'INNER'          _non_alpha_       st_RESERVED
'INSERT'         _non_alpha_       st_RESERVED
'INTO'           _non_alpha_       st_RESERVED
'IS'             _non_alpha_       st_RESERVED
'ISOLATION'      _non_alpha_       st_RESERVED
'JOIN'           _non_alpha_       st_RESERVED
'KEY'            _non_alpha_       st_RESERVED
'NULL'           _non_alpha_       st_RESERVED
'LEADING'        _non_alpha_       st_RESERVED
'LEFT'           _non_alpha_       st_RESERVED
'LEVEL'          _non_alpha_       st_RESERVED
'LIKE'           _non_alpha_       st_RESERVED
'MERGE'          _non_alpha_       st_RESERVED
'NAMES'          _non_alpha_       st_RESERVED
'NO'             _non_alpha_       st_RESERVED
'NOT'            _non_alpha_       st_RESERVED
'OF'             _non_alpha_       st_RESERVED
'ON'             _non_alpha_       st_RESERVED
'ONLY'           _non_alpha_       st_RESERVED
'OR'             _non_alpha_       st_RESERVED
'ORDER'          _non_alpha_       st_RESERVED
'OUTER'          _non_alpha_       st_RESERVED
'PARAMETER'      _non_alpha_       st_RESERVED
'PASSWORD'       _non_alpha_       st_RESERVED
'PIVOT'          _non_alpha_       st_RESERVED
'PLAN'           _non_alpha_       st_RESERVED
'POSITION'       _non_alpha_       st_RESERVED
'PROCEDURE'      _non_alpha_       st_RESERVED
'PROTECTED'      _non_alpha_       st_RESERVED
'PRIMARY'        _non_alpha_       st_RESERVED
'PRIVILEGES'     _non_alpha_       st_RESERVED
'READ'           _non_alpha_       st_RESERVED
'REFERENCES'     _non_alpha_       st_RESERVED
'RETAIN'         _non_alpha_       st_RESERVED
'RETURNING_VALUES' _non_alpha_     st_RESERVED
'RETURNS'        _non_alpha_       st_RESERVED
'REVOKE'         _non_alpha_       st_RESERVED
'RIGHT'          _non_alpha_       st_RESERVED
'ROLLBACK'       _non_alpha_       st_RESERVED
'SCHEMA'         _non_alpha_       st_RESERVED
'SELECT'         _non_alpha_       st_RESERVED
'SET'            _non_alpha_       st_RESERVED
'SHARED'         _non_alpha_       st_RESERVED
'SHADOW'         _non_alpha_       st_RESERVED
'SNAPSHOT'       _non_alpha_       st_RESERVED
'SOME'           _non_alpha_       st_RESERVED
'SUSPEND'        _non_alpha_       st_RESERVED
'TABLE'          _non_alpha_       st_RESERVED
'THEN'           _non_alpha_       st_RESERVED
'TO'             _non_alpha_       st_RESERVED
'TRAILING'       _non_alpha_       st_RESERVED
'TRANSFORM'      _non_alpha_       st_RESERVED
'TRANSACTION'    _non_alpha_       st_RESERVED
'TRIGGER'        _non_alpha_       st_RESERVED
'UNCOMMITTED'    _non_alpha_       st_RESERVED
'UNION'          _non_alpha_       st_RESERVED
'UNIQUE'         _non_alpha_       st_RESERVED
'UPDATE'         _non_alpha_       st_RESERVED
'USER'           _non_alpha_       st_RESERVED
'USING'          _non_alpha_       st_RESERVED
'VALUES'         _non_alpha_       st_RESERVED
'VARIABLE'       _non_alpha_       st_RESERVED
'VIEW'           _non_alpha_       st_RESERVED
'WAIT'           _non_alpha_       st_RESERVED
'WHEN'           _non_alpha_       st_RESERVED
'WHERE'          _non_alpha_       st_RESERVED
'WHILE'          _non_alpha_       st_RESERVED
'WITH'           _non_alpha_       st_RESERVED
'WORK'           _non_alpha_       st_RESERVED

%%handler
st_COMMENT_LINE         '[^\n]'?                    '\n'           _discard_
st_COMMENT_STAR         _all_chars_?                '*/'           _use_

%%tokens
st_STRING               __STD_PASCALSTRING
st_STRING               __STD_C_STRING
st_NUMBER               __STD_NUMBER_OR_FP
st_IDENTIFIER           __STD_IDENTIFIER

%%map
st_DEFAULT         st_DEFAULT
st_IDENTIFIER      st_IDENTIFIER
st_STRING          st_STRING
st_COMMENT         st_COMMENT
st_COMMENT_LINE    st_COMMENT
st_COMMENT_STAR    st_COMMENT
st_RESERVED        st_RESERVED
st_SYMBOL          st_SYMBOL
st_NUMBER          st_NUMBER

%%effects
st_DEFAULT              []                          _DEFAULT_FOREGROUND         _DEFAULT_BACKGROUND
st_IDENTIFIER           []                          clNavy                      _DEFAULT_BACKGROUND*
st_STRING               []                          clBlue                      _DEFAULT_BACKGROUND*
st_COMMENT              [fsItalic]                  clGray                    _DEFAULT_BACKGROUND*
st_RESERVED             [fsBold]                    _DEFAULT_FOREGROUND*        _DEFAULT_BACKGROUND*
st_NUMBER               []                          clGreen                     _DEFAULT_BACKGROUND*
st_SYMBOL               [fsBold]                    clMaroon                    _DEFAULT_BACKGROUND*


