/*
 * TSyntaxMemoParser Script
 * ------------------------
 * 
 * Title   :          VbNet Syntax Highlighting Parser for HomeSite 4.5.x and HomeSite 5.0
 * Version :          1.1
 * Description:       The VbNet Syntax Highlighting Parser is a color coding add-in developed
 *                    for use with HomeSite (tested in HomeSite 4.5.2) to add color coding
 *                    to files writen in Vb.NET (files with a ".vb" extension).
 * Author  :          Jose Luis Barreda (joseluiseco@hotmail.com)
 * Date    :          October 25, 2001
 * Last Modified:     November 9, 2001
 * Download:          http://www.wilk4.com/asp4hs/
 * Language:          VisualBasic.NET
 * Resources:         http://www.wilk4.com/asp4hs/tips.htm#writing_parsers,
 *                    http://www.webelement.net/homesite/tutorial1.htm,
 *                    http://www.xs4all.nl/~dbcons/dbsoftware/software/downloads/  (Script Builder 1.0),
 *                    Ray Dise's CSharp Parser (found in http://www.wilk4.com/asp4hs/aspdotnet4hs.htm),
 *                    Microsoft .NET Framework SDK Beta 2 Documentation.
 */

// Elements
#define DEFAULT                      0
#define VBNET_KEYWORD                1
#define VBNET_OPERATOR               2
#define VBNET_DIRECTIVE              3
#define VBNET_COMMENT                4
#define VBNET_STRING                 5
#define VBNET_IDENTIFIER             6
#define VBNET_SYMBOL                 7
#define VBNET_HEXNUMBER              8
#define VBNET_OCTNUMBER              9
#define VBNET_NUMBER                 10
#define VBNET_FUNCTION               11
#define VBNET_DATA_TYPE              12
#define VBNET_CONSTANT               13
#define VBNET_WHITE_SPACE            14
#define VBNET_LINE_CONTINUATION      15
#define NET_NAMESPACE                16
#define VBNET_ESCAPED_IDENTIFIER     17
#define VBNET_DATE                   18

// States
#define IN_DEFAULT          0

// Common Expressions
#define _ALPHA              '[_A-Za-z0-9]'
#define _NOT_ALPHA          '[^_A-Za-z0-9]'
#define _ALL_CHARS          '[\x00-\xFF]'
#define _DONT_CARE          _ALL_CHARS
#define _NO_CHARS           '[]'
#define _NOT_DOT_OR_ALPHA   '[^_A-Za-z0-9\.]'
#define _SPACE              '[\s]'

#define DEFAULT_BACKGROUND	clWhite
#define DEFAULT_FOREGROUND	clBlack

%%language
Name            =   'Vb.NET'
Case            =   __INSENSITIVE
Options         =   __DEFAULT_OPTIONS
//WordWrapColumn  =   _EDGE
//Gutter          =   _DEFAULT_GUTTER
EditableStyles  =   ('Default Text'           , DEFAULT),
                    ('Reserved Words'         , VBNET_KEYWORD),
                    ('Directives'             , VBNET_DIRECTIVE),
					('Functions'              , VBNET_FUNCTION),
                    ('Operators'              , VBNET_OPERATOR),
                    ('Comments'               , VBNET_COMMENT),
                    ('Identifier'             , VBNET_IDENTIFIER),
                    ('Symbols'                , VBNET_SYMBOL),
                    ('Number'                 , VBNET_NUMBER),
                    ('String'                 , VBNET_STRING),
					('Data Types'             , VBNET_DATA_TYPE),
					('VbNet Constants'        , VBNET_CONSTANT),
					('White Space'            , VBNET_WHITE_SPACE),
					('System Namespaces'      , NET_NAMESPACE)

ExampleText               = 'Imports System.Data\n\
\#Const cHola = "My New Parser" \'Comment\n\
Namespace VbNetParser\n\
\    Public Class myParser\n\
\        Public Function GetParser(ByVal strTest As String)\n\
\            Dim x As Integer = 10\n\
\            Dim strS As String = LTrim(strTest) & vbCrLf\n\
\        End Function\n\
\    End Class\n\
End Namespace'


%%words
'Abs'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Add'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'AddHandler'            _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'AddressOf'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Alias'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'And'                   _NOT_ALPHA               VBNET_OPERATOR           [IN_DEFAULT]
'AndAlso'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Ansi'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'AppActivate'           '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Append'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'As'                    _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Asc'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'AscW'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Assembly'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Atn'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Auto'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Beep'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Binary'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Boolean'               _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'ByRef'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Byte'                  _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'ByVal'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Call'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'CallByName'            '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Case'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Catch'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'CBool'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CByte'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CChar'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'CDate'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CDbl'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CDec'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Char'                  _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'ChDir'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'ChDrive'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Choose'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Chr'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CInt'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Class'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Clear'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'CLng'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CObj'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Command'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Compare'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Const'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Conversions'           '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Collection'            _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Cos'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CreateObject'          '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CShort'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CSng'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CStr'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CType'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'CurDir'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Date'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'DateAdd'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'DateDiff'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'DatePart'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'DateSerial'            '('                      VBNET_FUNCTION           [IN_DEFAULT]
'DateTime'              _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'DateValue'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Day'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'DDB'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Decimal'               _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'Declare'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Default'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Delegate'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'DeleteSetting'         '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Dim'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Dir'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Do'                    _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Double'                _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'Each'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Else'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'ElseIf'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'End'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'EndIf'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Enum'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Environ'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'EOF'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Erase'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Err'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Error'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'ErrorToString'         '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Event'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Exit'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Exp'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Explicit'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'False'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'FileAttr'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FileClose'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FileCopy'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FileDateTime'          '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FileLen'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FileOpen'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FilePut'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'FileWidth'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Filter'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Finally'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Fix'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'For'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Format'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FormatCurrency'        '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FormatDateTime'        '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FormatNumber'          '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FormatPercent'         '('                      VBNET_FUNCTION           [IN_DEFAULT]
'FreeFile'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Friend'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Function'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'FV'                    '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Get'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'GetAllSettings'        '('                      VBNET_FUNCTION           [IN_DEFAULT]
'GetAttr'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'GetChar'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'GetException'          '('                      VBNET_FUNCTION           [IN_DEFAULT]
'GetObject'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'GetSetting'            '('                      VBNET_FUNCTION           [IN_DEFAULT]
'GetType'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Goto'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Handles'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Hex'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Hour'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'If'                    _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'IIf'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Implements'            _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Imports'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'In'                    _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Inherits'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Input'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'InputBox'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'InputString'           '('                      VBNET_FUNCTION           [IN_DEFAULT]
'InStr'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'InStrRev'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Int'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Integer'               _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'Interface'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'IPmt'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'IRR'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Is'                    _NOT_ALPHA               VBNET_OPERATOR           [IN_DEFAULT]
'IsArray'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'IsDate'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'IsDbNull'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'IsError'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'IsNothing'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'IsNumeric'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'IsReference'           '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Item'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Join'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Kill'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'LBound'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'LCase'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Left'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Len'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Lib'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Like'                  _NOT_ALPHA               VBNET_OPERATOR           [IN_DEFAULT]
'LineInput'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Loc'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Lock'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'LOF'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Log'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Long'                  _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'Loop'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'LSet'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'LTrim'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Me'                    _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Mid'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Minute'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'MIRR'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'MkDir'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Mod'                   _NOT_ALPHA               VBNET_OPERATOR           [IN_DEFAULT]
'Module'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Month'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'MonthName'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'MsgBox'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'MustInherit'           _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'MustOverride'          _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'MyBase'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'MyClass'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Namespace'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'New'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Next'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Not'                   _NOT_ALPHA               VBNET_OPERATOR           [IN_DEFAULT]
'Nothing'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'NotInheritable'        _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'NotOverridable'        _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Now'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'NPer'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'NPV'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Object'                _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'Oct'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Off'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'On'                    _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Option'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Optional'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Or'                    _NOT_ALPHA               VBNET_OPERATOR           [IN_DEFAULT]
'OrElse'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Output'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Overloads'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Overridable'           _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Overrides'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'ParamArray'            _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Partition'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Pmt'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'PPmt'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Preserve'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Print'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Printline'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Private'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Property'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Protected'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Public'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'PV'                    '('                      VBNET_FUNCTION           [IN_DEFAULT]
'QBColor'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Raise'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'RaiseEvent'            _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Random'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Randomize'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Rate'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Read'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'ReadOnly'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'ReDim'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'REM'                   _DONT_CARE               VBNET_COMMENT            [IN_DEFAULT]
'Remove'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'RemoveHandler'         _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Rename'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Replace'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Reset'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Resume'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Return'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'RGB'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Right'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'RmDir'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Rnd'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Round'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'RSet'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'RTrim'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'SaveSetting'           '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Second'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Seek'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Select'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Set'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'SetAttr'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'SetException'          _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Sgn'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Shadows'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Shared'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Shell'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Short'                 _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'Sin'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Single'                _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'SLN'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Space'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Spc'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Split'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Sqr'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Static'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Step'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Stop'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Str'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'StrComp'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'StrConv'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'StrDup'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Strict'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'String'                _NOT_ALPHA               VBNET_DATA_TYPE          [IN_DEFAULT]
'StrReverse'            '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Structure'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Sub'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Switch'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'SYD'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'SyncLock'              _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Tab'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Tan'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Text'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Then'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Throw'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'TimeOfDay'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Timer'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'TimeSerial'            '('                      VBNET_FUNCTION           [IN_DEFAULT]
'TimeValue'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'To'                    _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Today'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Trim'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'True'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Try'                   _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'TypeName'              '('                      VBNET_FUNCTION           [IN_DEFAULT]
'TypeOf'                _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'UBound'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'UCase'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Unicode'               _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Unlock'                '('                      VBNET_FUNCTION           [IN_DEFAULT]
'Until'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'UseDefault'            _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Val'                   '('                      VBNET_FUNCTION           [IN_DEFAULT]
'vbAbort'               _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbAbortRetryIgnore'    _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbApplicationModal'    _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbArchive'             _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbBack'                _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbBinaryCompare'       _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbCancel'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbCritical'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbCr'                  _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbCrLf'                _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbDefaultButton1'      _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbDefaultButton2'      _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbDefaultButton3'      _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbDirectory'           _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbExclamation'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbFirstFourDays'       _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbFirstFullWeek'       _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbFirstJan1'           _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbFormFeed'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbFriday'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbGeneralDate'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbGet'                 _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbHidden'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbHide'                _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbHiragana'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbIgnore'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbInformation'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbKatakana'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbLf'                  _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbLinguisticCasing'    _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbLongDate'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbLongTime'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbLowerCase'           _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMaximizedFocus'      _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMethod'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMinimizedFocus'      _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMinimizedNoFocus'    _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMonday'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMsgBoxHelp'          _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMsgBoxRight'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMsgBoxRtlReading'    _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbMsgBoxSetForeground' _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbNarrow'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbNewLine'             _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbNo'                  _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbNormal'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbNormalFocus'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbNormalNoFocus'       _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbNullChar'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbNullString'          _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbObjectError'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbOK'                  _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbOKCancel'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbOKOnly'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbProperCase'          _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbQuestion'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbReadOnly'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbRetry'               _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbRetryCancel'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbSaturday'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbSet'                 _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbShortDate'           _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbShortTime'           _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbSimplifiedChinese'   _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbSunday'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbSystem'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbSystemModal'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbTab'                 _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbTextCompare'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbThursday'            _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbTraditionalChinese'  _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbTuesday'             _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbUpperCase'           _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbUseSystem'           _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbUseSystemDayOfWeek'  _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbVerticalTab'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbVolume'              _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbWednesday'           _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbWide'                _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbYes'                 _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbYesNo'               _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'vbYesNoCancel'         _NOT_ALPHA               VBNET_CONSTANT           [IN_DEFAULT]
'Weekday'               '('                      VBNET_FUNCTION           [IN_DEFAULT]
'WeekdayName'           '('                      VBNET_FUNCTION           [IN_DEFAULT]
'When'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'While'                 _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'With'                  _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'WithEvents'            _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Write'                 '('                      VBNET_FUNCTION           [IN_DEFAULT]
'WriteLine'             '('                      VBNET_FUNCTION           [IN_DEFAULT]
'WriteOnly'             _NOT_ALPHA               VBNET_KEYWORD            [IN_DEFAULT]
'Xor'                   _NOT_ALPHA               VBNET_OPERATOR           [IN_DEFAULT]
'Year'                  '('                      VBNET_FUNCTION           [IN_DEFAULT]
'#Const'                _DONT_CARE               VBNET_DIRECTIVE          [IN_DEFAULT]
'#Else'                 _DONT_CARE               VBNET_DIRECTIVE          [IN_DEFAULT]
'#End Region'           _DONT_CARE               VBNET_DIRECTIVE          [IN_DEFAULT]
'#End ExternalSource'   _DONT_CARE               VBNET_DIRECTIVE          [IN_DEFAULT]
'#ExternalSource'       _DONT_CARE               VBNET_DIRECTIVE          [IN_DEFAULT]
'#If'                   _DONT_CARE               VBNET_DIRECTIVE          [IN_DEFAULT]
'#Region'               _DONT_CARE               VBNET_DIRECTIVE          [IN_DEFAULT]
'#Then'                 _DONT_CARE               VBNET_DIRECTIVE          [IN_DEFAULT]
'_'                     _SPACE                   VBNET_LINE_CONTINUATION  [IN_DEFAULT]
'+'                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'-'                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'*'                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'/'                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'\\'                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'&'                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'<>'                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'>'                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'<'                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'>='                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'<='                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'='                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'^'                     _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'+='                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'-='                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'*='                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'/='                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'\\='                   _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'&='                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'^='                    _DONT_CARE               VBNET_OPERATOR           [IN_DEFAULT]
'('                     _DONT_CARE               VBNET_SYMBOL             [IN_DEFAULT]
')'                     _DONT_CARE               VBNET_SYMBOL             [IN_DEFAULT]
//']'                     _DONT_CARE               VBNET_SYMBOL             [IN_DEFAULT]
'\.'                    _DONT_CARE               VBNET_SYMBOL             [IN_DEFAULT]
'!'                     _DONT_CARE               VBNET_SYMBOL             [IN_DEFAULT]
','                     _DONT_CARE               VBNET_SYMBOL             [IN_DEFAULT]
':'                     _DONT_CARE               VBNET_SYMBOL             [IN_DEFAULT]
'\''                    _DONT_CARE               VBNET_COMMENT            [IN_DEFAULT]
//'"'                     _DONT_CARE               VBNET_STRING             [IN_DEFAULT] 'Commented to fix empty string bug
'&H'                    _DONT_CARE               VBNET_HEXNUMBER          [IN_DEFAULT]
'&O'                    _DONT_CARE               VBNET_OCTNUMBER          [IN_DEFAULT]
'['                     _DONT_CARE               VBNET_ESCAPED_IDENTIFIER [IN_DEFAULT]
'#'                     _SPACE                   VBNET_DATE               [IN_DEFAULT]

'Microsoft\.CSharp'                                       _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'Microsoft\.JScript'                                      _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'Microsoft\.VisualBasic'                                  _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'Microsoft\.Win32'                                        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System'                                                  _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.CodeDom'                                         _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.CodeDom\.Compiler'                               _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Collections'                                     _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Collections\.Specialized'                        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.ComponentModel'                                  _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.ComponentModel\.Design'                          _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.ComponentModel\.Design\.Serialization'           _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Configuration'                                   _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Configuration\.Assemblies'                       _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Configuration\.Install'                          _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Data'                                            _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Data\.Common'                                    _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Data\.OleDb'                                     _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Data\.SqlClient'                                 _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Data\.SqlTypes'                                  _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Diagnostics'                                     _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Diagnostics\.SymbolStore'                        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.DirectoryServices'                               _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Drawing'                                         _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Drawing\.Design'                                 _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Drawing\.Drawing2D'                              _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Drawing\.Imaging'                                _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Drawing\.Printing'                               _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Drawing\.Text'                                   _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.EnterpriseServices'                              _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.EnterpriseServices\.CompensatingResourceManager' _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Globalization'                                   _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.IO'                                              _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.IO\.IsolatedStorage'                             _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Management'                                      _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Management\.Instrumentation'                     _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Messaging'                                       _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Net'                                             _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Net\.Sockets'                                    _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Reflection'                                      _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Reflection\.Emit'                                _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Resources'                                       _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
//To do: Runtime namespaces
'System\.Security'                                        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Security\.Cryptography'                          _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Security\.Cryptography\.X509Certificates'        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Security\.Cryptography\.Xml'                     _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Security\.Permissions'                           _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Security\.Policy'                                _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Security\.Principal'                             _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.ServiceProcess'                                  _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Text'                                            _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Text\.RegularExpressions'                        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Threading'                                       _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Timers'                                          _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web'                                             _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Caching'                                    _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Configuration'                              _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Hosting'                                    _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Mail'                                       _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Security'                                   _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Services'                                   _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Services\.Description'                      _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Services\.Discovery'                        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.Services\.Protocols'                        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.SessionState'                               _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.UI'                                         _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.UI\.Design'                                 _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.UI\.Design\.WebControls'                    _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.UI\.HtmlControls'                           _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Web\.UI\.WebControls'                            _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Windows\.Forms'                                  _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Windows\.Forms\.Design'                          _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Xml'                                             _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Xml\.Schema'                                     _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Xml\.Serialization'                              _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Xml\.XPath'                                      _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]
'System\.Xml\.Xsl'                                        _NOT_DOT_OR_ALPHA        NET_NAMESPACE            [IN_DEFAULT]

%%handlers
VBNET_COMMENT              __STD_JS_LINE_COMMENT //_DONT_CARE             '\n'           _discard_
VBNET_HEXNUMBER            '[0-9A-Fa-f]'          '[silSIL\s\n]' _use_ //'[^0-9a-fA-F]' _discard_
VBNET_OCTNUMBER            '[0-7]'                '[silSIL\s\n]' _use_
//VBNET_STRING               _DONT_CARE             '"'            _use_ //__STD_C_STRING 'Commented to fix empty string bug
VBNET_ESCAPED_IDENTIFIER   '[a-zA-Z0-9_\.\s]'?    '\]'           _use_
VBNET_DATE                 '[0-9aApPmM:/\-\s]'    '#'            _use_

%%tokens
VBNET_IDENTIFIER           __STD_IDENTIFIER //'[a-zA-Z_]'  '[a-zA-Z0-9_\.]'?  '[^a-zA-Z0-9_\.]' _discard_
VBNET_NUMBER               __STD_NUMBER_OR_FP
VBNET_WHITE_SPACE          '[\x00-\s]'  '[\x00-\s]'?        '[^\x00-\s]'      _discard_
VBNET_STRING               __STD_C_STRING

%%effects
DEFAULT                   []             DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
VBNET_KEYWORD             []             clBlue                  DEFAULT_BACKGROUND*
VBNET_SYMBOL              [fsBold]       clBlack                 DEFAULT_BACKGROUND*
VBNET_OPERATOR            [fsBold]       DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
VBNET_DIRECTIVE           []             clGreen                 DEFAULT_BACKGROUND*
VBNET_FUNCTION            [fsBold]       clNavy                  DEFAULT_BACKGROUND*
VBNET_COMMENT             []             clGreen                 DEFAULT_BACKGROUND*
VBNET_STRING              [fsBold]       clTeal                  DEFAULT_BACKGROUND*
VBNET_IDENTIFIER          []             DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
VBNET_NUMBER              []             clRed                   DEFAULT_BACKGROUND*
VBNET_DATA_TYPE           [fsBold]       clBlue                  DEFAULT_BACKGROUND*
VBNET_CONSTANT            [fsBold]       clNavy                  DEFAULT_BACKGROUND*
VBNET_WHITE_SPACE         []             DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
VBNET_LINE_CONTINUATION   []             DEFAULT_FOREGROUND*     DEFAULT_BACKGROUND*
NET_NAMESPACE             [fsBold]       clMaroon                DEFAULT_BACKGROUND*
VBNET_DATE                [fsBold]       clNavy                  DEFAULT_BACKGROUND*

%%map
DEFAULT                  DEFAULT
VBNET_KEYWORD            VBNET_KEYWORD
VBNET_OPERATOR           VBNET_OPERATOR
VBNET_DIRECTIVE          VBNET_DIRECTIVE
VBNET_COMMENT            VBNET_COMMENT
VBNET_FUNCTION           VBNET_FUNCTION
VBNET_STRING             VBNET_STRING
VBNET_IDENTIFIER         VBNET_IDENTIFIER
VBNET_SYMBOL             VBNET_SYMBOL
VBNET_NUMBER             VBNET_NUMBER
VBNET_HEXNUMBER          VBNET_NUMBER
VBNET_OCTNUMBER          VBNET_NUMBER
VBNET_DATA_TYPE          VBNET_DATA_TYPE
VBNET_CONSTANT           VBNET_CONSTANT
VBNET_WHITE_SPACE        VBNET_WHITE_SPACE
VBNET_LINE_CONTINUATION  VBNET_LINE_CONTINUATION
NET_NAMESPACE            NET_NAMESPACE
VBNET_ESCAPED_IDENTIFIER  VBNET_IDENTIFIER
VBNET_DATE               VBNET_DATE