/******************************************************************************
	CSS Color Coding Script Extension
	by B. Collier Jones
	Version 4.5.1
	
	Current Version Revision History:
	01/19/2000 - Rewritten from HTML+ 4.0 Beta
			   - Isolated CSS information into separate file to work with
				 new embedded languages support in TSyntaxMemo 4.0 for
				 HomeSite 4.5.1
			   - Added Style: 'CSS Units'
			   - Added Style: 'CSS Punctuation'
			   - Removed Style: 'CSS Declaration' - removed since there aren't
			     enough editable styles in 4.5.1 (try to get increased)
			   - Added TopStyle-ish behavior of color properties red until
			     they are recognized among a list of CSS-specified properties
	01/29/2000 - Fixed Anchors, ContextStates, and BoundStates so that
				 stuff around declarations does dance around
	02/04/2000 - Made declaration background same as CSS Default
******************************************************************************/
// Elements
#define CSS_BASE					STYLE_SHEET_BASE
#define HTML_STYLE					CSS_BASE + 0
#define HTML_STYLE_START_START		CSS_BASE + 1
#define HTML_STYLE_START_STOP		CSS_BASE + 2
#define HTML_STYLE_STOP_START		CSS_BASE + 3
#define HTML_STYLE_STOP_STOP		CSS_BASE + 4
#define CSS_DEFAULT					CSS_BASE + 5
#define CSS_COMMENT					CSS_BASE + 6
#define CSS_COMMENT_START			CSS_BASE + 7
#define CSS_COMMENT_STOP			CSS_BASE + 8
#define CSS_DECLARATION				CSS_BASE + 9
#define CSS_DECLARATION_START		CSS_BASE + 10
#define CSS_DECLARATION_STOP		CSS_BASE + 11
#define CSS_IMPORTANT				CSS_BASE + 12
#define CSS_PROPERTY				CSS_BASE + 13
#define CSS_SELECTOR				CSS_BASE + 14
#define CSS_VALUE					CSS_BASE + 15
#define CSS_VALUE_START				CSS_BASE + 16
#define CSS_VALUE_STOP				CSS_BASE + 17
#define CSS_UNIT					CSS_BASE + 18
#define CSS_PUNCTUATION				CSS_BASE + 19

// States
#define IN_HTML_STYLE_START			CSS_BASE + 0
#define IN_HTML_STYLE_STOP			CSS_BASE + 1
#define IN_CSS_DEFAULT				CSS_BASE + 2
#define IN_CSS_COMMENT				CSS_BASE + 3
#define IN_CSS_DECLARATION			CSS_BASE + 4
#define IN_CSS_VALUE				CSS_BASE + 5

#define CSS_STATES 					STYLE_SHEET_BASE..STYLE_SHEET_MAX

%%language
Anchor							+=	[HTML_STYLE_START_START HTML_STYLE_STOP_START]
BoundStates						+=	[IN_HTML_STYLE_START IN_HTML_STYLE_STOP]
ContextStates					=	(HTML_STYLE_START_START [IN_HTML_STYLE_START]),
									(HTML_STYLE_STOP_START [IN_HTML_STYLE_STOP])
EditableStyles						('HTML Style'				, HTML_STYLE),
									('CSS Default'				, CSS_DEFAULT),
									//('CSS Declarations'			, CSS_DECLARATION),
									('CSS Comments'				, CSS_COMMENT),
									('CSS Important'			, CSS_IMPORTANT),
									('CSS Properties'			, CSS_PROPERTY),
									('CSS Selectors'			, CSS_SELECTOR),
									('CSS Units'				, CSS_UNIT),
									('CSS Values'				, CSS_VALUE),
									('CSS Punctuation'			, CSS_PUNCTUATION)
ExampleText						+=	'------- CSS -------\n\
									\<style type="text/css">\n\
									\     h1 {\n\
									\		font-family: Verdana;\n\
									\		font-size: 8pt;\n\
									\		font-style: none;\n\
									\     }\n\
									\</style>\n'

%%words
'<style'				NOT_ALPHA			HTML_STYLE_START_START	[IN_DEFAULT]
'>'						DONT_CARE			HTML_STYLE_START_STOP	[IN_HTML_STYLE_START]
'</style'				NOT_ALPHA			HTML_STYLE_STOP_START	[IN_CSS_DEFAULT]
'>'						DONT_CARE			HTML_STYLE_STOP_STOP	[IN_HTML_STYLE_STOP]
// CSS Comment
'<!--'					DONT_CARE			CSS_COMMENT				[IN_CSS_DEFAULT]
'-->'					DONT_CARE			CSS_COMMENT				[IN_CSS_DEFAULT]
'\/*'					DONT_CARE			CSS_COMMENT_START		[CSS_STATES]
'*\/'					DONT_CARE			CSS_COMMENT_STOP		[IN_CSS_COMMENT]
// CSS Declaration
'{'						DONT_CARE			CSS_DECLARATION_START	[IN_CSS_DEFAULT]
'}'						DONT_CARE			CSS_DECLARATION_STOP	[IN_CSS_DECLARATION IN_CSS_VALUE]
// CSS Important
'!important'			DONT_CARE			CSS_IMPORTANT			[IN_CSS_VALUE]
// CSS Units
'cm'					NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
'em'					NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
'ex'					NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
'in'					NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
'mm'					NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
'pc'					NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
'pt'					NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
'px'					NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
'%'						NOT_ALPHA			CSS_UNIT				[IN_CSS_VALUE]
// CSS Value
':'						DONT_CARE			CSS_VALUE_START			[IN_CSS_DECLARATION]
';'						DONT_CARE			CSS_VALUE_STOP			[IN_CSS_VALUE]

%%kwtables
ForState [IN_CSS_DECLARATION] endswith '[ :]' (
	// ASP Constants
	CSS_PROPERTY		is	'background', 'background-attachment', 'background-color',
							'background-image', 'background-position', 'background-repeat',
							'border', 'border-collapse', 'border-color', 'border-spacing',
							'border-style', 'border-top', 'border-right', 'border-bottom',
							'border-left', 'border-top-color', 'border-right-color',
							'border-bottom-color', 'border-left-color', 'border-top-style',
							'border-right-style', 'border-bottom-style', 'border-left-style',
							'border-top-width', 'border-right-width', 'border-bottom-width',
							'border-left-width', 'border-width', 'bottom', 'caption-side',
							'clear', 'clip', 'color', 'content', 'counter-increment',
							'counter-reset', 'cursor', 'direction', 'display',
							'empty-cells', 'float', 'font', 'font-family', 'font-size',
							'font-size-adjust', 'font-stretch', 'font-style',
							'font-variant', 'font-weight', 'height', 'left',
							'letter-spacing', 'line-height', 'list-style',
							'list-style-image', 'list-style-position', 'list-style-type',
							'margin', 'margin-top', 'margin-right', 'margin-bottom',
							'margin-left', 'marker-offset', 'marks', 'max-height',
							'max-width', 'min-height', 'min-width', 'orphans',
							'outline', 'outline-color', 'outline-style', 'outline-width',
							'overflow', 'padding', 'padding-top', 'padding-right',
							'padding-bottom', 'padding-left', 'page', 'page-break-after',
							'page-break-before', 'page-break-inside', 'position',
							'quotes', 'right', 'size', 'table-layout', 'text-align',
							'text-decoration', 'text-indent', 'text-shadow',
							'text-transform', 'top', 'unicode-bidi', 'vertical-align',
							'visibility', 'white-space', 'widows', 'width',
							'word-spacing', 'z-index'
)

%%tokens
InState IN_HTML_STYLE_START (
	HTML_STYLE			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_STYLE_STOP (
	HTML_STYLE			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_CSS_DEFAULT (
	CSS_DEFAULT			'[^.#A-Za-z]'		DONT_CARE?			DONT_CARE			_discard_
	CSS_SELECTOR		'[.#A-Za-z]'		DONT_CARE?			'[^A-Za-z0-9:]'		_discard_
)

InState IN_CSS_COMMENT (
	CSS_COMMENT			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_CSS_DECLARATION (
	CSS_DEFAULT			'[^A-Za-z0-9\-]'	DONT_CARE?			DONT_CARE			_discard_
	CSS_DECLARATION		'[A-Za-z0-9\-]'		DONT_CARE?			DONT_CARE			_discard_
)

InState IN_CSS_VALUE (
	CSS_VALUE			DONT_CARE			DONT_CARE?			DONT_CARE		_discard_
)

%%states
HTML_STYLE_START_START	(-[IN_DEFAULT]						+[IN_HTML_STYLE_START])
HTML_STYLE_START_STOP	(-[IN_HTML_STYLE_START]				+[IN_CSS_DEFAULT])

HTML_STYLE_STOP_START	(-[IN_CSS_DEFAULT]					+[IN_HTML_STYLE_STOP])
HTML_STYLE_STOP_STOP	(-[IN_HTML_STYLE_STOP]				+[IN_DEFAULT])

CSS_COMMENT_START		push (+[IN_CSS_COMMENT]				-[CSS_STATES])
CSS_COMMENT_STOP		pop ()

CSS_DECLARATION_START	(+[IN_CSS_DECLARATION]				-[IN_CSS_DEFAULT])
CSS_DECLARATION_STOP	(-[IN_CSS_DECLARATION IN_CSS_VALUE]		+[IN_CSS_DEFAULT])

CSS_VALUE_START			(+[IN_CSS_VALUE]					-[IN_CSS_DECLARATION])
CSS_VALUE_STOP			(-[IN_CSS_VALUE]					+[IN_CSS_DECLARATION])

%%effects
HTML_STYLE				[]					clBlue					DEFAULT_BACKGROUND*
CSS_DEFAULT				[]					clBlue					DEFAULT_BACKGROUND*
CSS_DECLARATION			[]					clRed					DEFAULT_BACKGROUND*
CSS_COMMENT				[]					clGray					DEFAULT_BACKGROUND*
CSS_IMPORTANT			[fsBold]			clRed					DEFAULT_BACKGROUND*
CSS_PROPERTY			[]					clBlack					DEFAULT_BACKGROUND*
CSS_SELECTOR			[fsBold]			clMaroon				DEFAULT_BACKGROUND*
CSS_UNIT				[]					clBlue					DEFAULT_BACKGROUND*
CSS_VALUE				[]					clPurple				DEFAULT_BACKGROUND*
CSS_PUNCTUATION			[fsBold]			clNavy					DEFAULT_BACKGROUND*

%%map
HTML_STYLE				HTML_STYLE
HTML_STYLE_START_START	HTML_STYLE
HTML_STYLE_START_STOP	HTML_STYLE
HTML_STYLE_STOP_START	HTML_STYLE
HTML_STYLE_STOP_STOP	HTML_STYLE
CSS_DEFAULT				CSS_DEFAULT
CSS_DECLARATION			CSS_DECLARATION
CSS_DECLARATION_START	CSS_PUNCTUATION
CSS_DECLARATION_STOP	CSS_PUNCTUATION
CSS_COMMENT				CSS_COMMENT
CSS_COMMENT_START		CSS_COMMENT
CSS_COMMENT_STOP		CSS_COMMENT
CSS_IMPORTANT			CSS_IMPORTANT
CSS_PROPERTY			CSS_PROPERTY
CSS_SELECTOR			CSS_SELECTOR
CSS_UNIT				CSS_UNIT
CSS_VALUE				CSS_VALUE
CSS_VALUE_START			CSS_PUNCTUATION
CSS_VALUE_STOP			CSS_PUNCTUATION
CSS_PUNCTUATION			CSS_PUNCTUATION