/******************************************************************************
	HTML Color Coding Script Extension
	by B. Collier Jones
	Version 4.5.1
	
	Current Version Revision History:
	01/19/2000 - Rewritten from HTML+ 4.0 Beta
			   - Isolated HTML information into separate file to work with
				 new embedded languages support in TSyntaxMemo 4.0 for
				 HomeSite 4.5.1
			   - Removed Style: 'HTML Script' - moved to client-side extension
			   - Removed Style: 'HTML Style' - moved to style extension
	01/20/2000 - OOPS! Forgot to add HTML ContextStates/BoundStates/Anchors
	01/22/2000 - Changed default color of forms to Organge and Frames to a
				 Soft Blue so they are easily distinguishable.  Using orange was
				 based on personal preferences and suggestions from users.
				 Forms are rather important to ASP programing and so should stand
				 out just as much as the ASP. (but not in the same way)
	02/02/2000 - Added 'HTML Illegal Characters' style.
	02/04/2000 - Made <button> a form element
	10/28/2000 - Changed '<' for HTML_TAG_START to require an alpha immediately
				 after.  This fixes problems with SQL statements in CFML.
******************************************************************************/
// Elements
#define HTML_BASE					HTML_ELEMENT_BASE
#define HTML_BLOCK					HTML_BASE + 0
#define HTML_BLOCK_START			HTML_BASE + 1
#define HTML_BLOCK_STOP				HTML_BASE + 2
#define HTML_TAG					HTML_BASE + 3
#define HTML_TAG_START				HTML_BASE + 4
#define HTML_TAG_STOP				HTML_BASE + 5
#define HTML_SPECIAL				HTML_BASE + 6
#define HTML_COMMENT				HTML_BASE + 7
#define HTML_COMMENT_START			HTML_BASE + 8
#define HTML_COMMENT_STOP			HTML_BASE + 9
#define HTML_FORM					HTML_BASE + 10
#define HTML_FORM_START				HTML_BASE + 11
#define HTML_FORM_STOP				HTML_BASE + 12
#define HTML_FORMAT					HTML_BASE + 13
#define HTML_FORMAT_START			HTML_BASE + 14
#define HTML_FORMAT_STOP			HTML_BASE + 15
#define HTML_FRAME					HTML_BASE + 16
#define HTML_FRAME_START			HTML_BASE + 17
#define HTML_FRAME_STOP				HTML_BASE + 18
#define HTML_IMAGE					HTML_BASE + 19
#define HTML_IMAGE_START			HTML_BASE + 20
#define HTML_IMAGE_STOP				HTML_BASE + 21
#define HTML_IMAGEMAP				HTML_BASE + 22
#define HTML_IMAGEMAP_START			HTML_BASE + 23
#define HTML_IMAGEMAP_STOP			HTML_BASE + 24
#define HTML_LINK					HTML_BASE + 25
#define HTML_LINK_START				HTML_BASE + 26
#define HTML_LINK_STOP				HTML_BASE + 27
#define HTML_LIST					HTML_BASE + 28
#define HTML_LIST_START				HTML_BASE + 29
#define HTML_LIST_STOP				HTML_BASE + 30
#define HTML_MEDIA					HTML_BASE + 31
#define HTML_MEDIA_START			HTML_BASE + 32
#define HTML_MEDIA_STOP				HTML_BASE + 33
#define HTML_STRUCTURE				HTML_BASE + 34
#define HTML_STRUCTURE_START		HTML_BASE + 35
#define HTML_STRUCTURE_STOP			HTML_BASE + 36
#define HTML_TABLE					HTML_BASE + 37
#define HTML_TABLE_START			HTML_BASE + 38
#define HTML_TABLE_STOP				HTML_BASE + 39
#define HTML_WHITESPACE				HTML_BASE + 40
#define HTML_WHITESPACE_START		HTML_BASE + 41
#define HTML_WHITESPACE_STOP		HTML_BASE + 42
#define HTML_STYLE					HTML_BASE + 43
#define HTML_SCRIPT					HTML_BASE + 48

// States
#define IN_HTML_BLOCK				HTML_BASE + 0
#define IN_HTML_COMMENT				HTML_BASE + 1
#define IN_HTML_FORM				HTML_BASE + 2
#define IN_HTML_FORMAT				HTML_BASE + 3
#define IN_HTML_FRAME				HTML_BASE + 4
#define IN_HTML_IMAGE				HTML_BASE + 5
#define IN_HTML_IMAGEMAP			HTML_BASE + 6
#define IN_HTML_LINK				HTML_BASE + 7
#define IN_HTML_LIST				HTML_BASE + 8
#define IN_HTML_MEDIA				HTML_BASE + 9
#define IN_HTML_STRUCTURE			HTML_BASE + 14
#define IN_HTML_TABLE				HTML_BASE + 18
#define IN_HTML_TAG					HTML_BASE + 19
#define IN_HTML_WHITESPACE			HTML_BASE + 20

// Language Declaration
%%language
Anchor							+=	[HTML_BLOCK_START HTML_COMMENT_START HTML_FORM_START HTML_FORMAT_START HTML_FRAME_START HTML_IMAGE_START HTML_IMAGEMAP_START HTML_LINK_START HTML_LIST_START HTML_MEDIA_START HTML_STRUCTURE_START HTML_TAG_START HTML_TABLE_START HTML_WHITESPACE_START]
BoundStates						+=	[IN_HTML_BLOCK IN_HTML_COMMENT IN_HTML_FORM IN_HTML_FORMAT IN_HTML_FRAME IN_HTML_IMAGE IN_HTML_IMAGEMAP IN_HTML_LINK IN_HTML_LIST IN_HTML_MEDIA IN_HTML_STRUCTURE IN_HTML_TABLE IN_HTML_TAG IN_HTML_WHITESPACE]
ContextStates					=	(HTML_BLOCK_START [IN_HTML_BLOCK]),
									(HTML_COMMENT_START [IN_HTML_COMMENT]),
									(HTML_FORM_START [IN_HTML_FORM]),
									(HTML_FORMAT_START [IN_HTML_FORMAT]),
									(HTML_FRAME_START [IN_HTML_FRAME]),
									(HTML_IMAGE_START [IN_HTML_IMAGE]),
									(HTML_IMAGEMAP_START [IN_HTML_IMAGEMAP]),
									(HTML_LINK_START [IN_HTML_LINK]),
									(HTML_LIST_START [IN_HTML_LIST]),
									(HTML_MEDIA_START [IN_HTML_MEDIA]),
									(HTML_STRUCTURE_START [IN_HTML_STRUCTURE]),
									(HTML_TABLE_START [IN_HTML_TABLE]),
									(HTML_TAG_START [IN_HTML_TAG]),
									(HTML_WHITESPACE_START [IN_HTML_WHITESPACE])
EditableStyles						('HTML Blocks'					, HTML_BLOCK),
									('HTML Comments'				, HTML_COMMENT),
									('HTML Forms'					, HTML_FORM),
									('HTML Formatting'				, HTML_FORMAT),
									('HTML Frames'					, HTML_FRAME),
									('HTML Images'					, HTML_IMAGE),
									('HTML Image Maps'				, HTML_IMAGEMAP),
									('HTML Links'					, HTML_LINK),
									('HTML Lists'					, HTML_LIST),
									('HTML Media'					, HTML_MEDIA),
									('HTML Special Characters'		, HTML_SPECIAL),
									('HTML Structure'				, HTML_STRUCTURE),
									('HTML Unknown Tags'			, HTML_TAG),
									('HTML Tables'					, HTML_TABLE),
									('HTML Whitespace'				, HTML_WHITESPACE)
ExampleText						+=	'------- HTML -------\n\
									\<html>\n\
									\<body>\n\
									\<h1>Example 1</h1>\n\
									\<!-- Comment -->\n\
									\<table cellpadding="0"><tr>\n\
									\     <td><b>Value 1 &amp;</b></td>\n\
									\</tr></table>\n\
									\<form action="test.pl"><input type="submit" value="go"></form>\n\
									\<img src="animation.gif" height="40">\n\
									\<iframe src="test.html">\n\
									\<map name="Main"></map>\n\
									\<a href="http://www.Macromedia.com">Macromedia</a>\n\
									\<ul><li>Item 1</li><li>Item 2</li></ul>\n\
									\<object id="Movie1"></object>\n\
									\<footag>\n\
									\<hr>\n\
									\</html>\n'

%%words
// Block Elements
'<address'				NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</address'				NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<blockquote'			NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</blockquote'			NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<center'				NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</center'				NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<div'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</div'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<h1'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</h1'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<h2'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</h2'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<h3'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</h3'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<h4'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</h4'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<h5'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</h5'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<h6'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</h6'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<p'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</p'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'<pre'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'</pre'					NOT_ALPHA			HTML_BLOCK_START		[IN_DEFAULT]
'>'						DONT_CARE			HTML_BLOCK_STOP			[IN_HTML_BLOCK]
// HTML Comments
'<!--'					DONT_CARE			HTML_COMMENT_START		[IN_DEFAULT]
'-->'					DONT_CARE			HTML_COMMENT_STOP		[IN_HTML_COMMENT]
// HTML Form
'<button'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</button'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<fieldset'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</fieldset'			NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<form'					NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</form'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<input'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<isindex'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<label'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</label'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<legend'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</legend'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<optgroup'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</optgroup'			NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<option'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</option'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<select'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</select'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'<textarea'				NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'</textarea'			NOT_ALPHA			HTML_FORM_START			[IN_DEFAULT]
'>'						DONT_CARE			HTML_FORM_STOP			[IN_HTML_FORM]
// HTML Format
'<abbr'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</abbr'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<acronym'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</acronym'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<b'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</b'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<bdo'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</bdo'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<big'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</big'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<cite'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</cite'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<code'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</code'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<del'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</del'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<dfn'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</dfn'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<em'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</em'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<font'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</font'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<i'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</i'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<ins'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</ins'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<kbd'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</kbd'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<q'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</q'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<s'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</s'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<samp'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</samp'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<small'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</small'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<span'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</span'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<strike'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</strike'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<strong'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</strong'				NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<sub'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</sub'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<sup'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</sup'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<tt'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</tt'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<u'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</u'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'<var'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'</var'					NOT_ALPHA			HTML_FORMAT_START		[IN_DEFAULT]
'>'						DONT_CARE			HTML_FORMAT_STOP		[IN_HTML_FORMAT]
// HTML Frame
'<frame'				NOT_ALPHA			HTML_FRAME_START		[IN_DEFAULT]
'</frame'				NOT_ALPHA			HTML_FRAME_START		[IN_DEFAULT]
'<frameset'				NOT_ALPHA			HTML_FRAME_START		[IN_DEFAULT]
'</frameset'			NOT_ALPHA			HTML_FRAME_START		[IN_DEFAULT]
'<iframe'				NOT_ALPHA			HTML_FRAME_START		[IN_DEFAULT]
'</iframe'				NOT_ALPHA			HTML_FRAME_START		[IN_DEFAULT]
'<noframes'				NOT_ALPHA			HTML_FRAME_START		[IN_DEFAULT]
'</noframes'			NOT_ALPHA			HTML_FRAME_START		[IN_DEFAULT]
'>'						DONT_CARE			HTML_FRAME_STOP			[IN_HTML_FRAME]
// HTML Image
'<img'					NOT_ALPHA			HTML_IMAGE_START		[IN_DEFAULT]
'>'						DONT_CARE			HTML_IMAGE_STOP			[IN_HTML_IMAGE]
// HTML Image Map
'<area'					NOT_ALPHA			HTML_IMAGEMAP_START		[IN_DEFAULT]
'<map'					NOT_ALPHA			HTML_IMAGEMAP_START		[IN_DEFAULT]
'</map'					NOT_ALPHA			HTML_IMAGEMAP_START		[IN_DEFAULT]
'>'						DONT_CARE			HTML_IMAGEMAP_STOP		[IN_HTML_IMAGEMAP]
// HTML Link
'<a'					NOT_ALPHA			HTML_LINK_START			[IN_DEFAULT]
'</a'					NOT_ALPHA			HTML_LINK_START			[IN_DEFAULT]
'>'						DONT_CARE			HTML_LINK_STOP			[IN_HTML_LINK]
// HTML List
'<dd'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'</dd'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'<dir'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'</dir'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'<dl'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'</dl'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'<dt'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'</dt'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'<menu'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'</menu'				NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'<ol'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'</ol'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'<ul'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'</ul'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'<li'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'</li'					NOT_ALPHA			HTML_LIST_START			[IN_DEFAULT]
'>'						DONT_CARE			HTML_LIST_STOP			[IN_HTML_LIST]
// HTML Media
'<applet'				NOT_ALPHA			HTML_MEDIA_START		[IN_DEFAULT]
'</applet'				NOT_ALPHA			HTML_MEDIA_START		[IN_DEFAULT]
'<object'				NOT_ALPHA			HTML_MEDIA_START		[IN_DEFAULT]
'</object'				NOT_ALPHA			HTML_MEDIA_START		[IN_DEFAULT]
'<param'				NOT_ALPHA			HTML_MEDIA_START		[IN_DEFAULT]
'>'						DONT_CARE			HTML_MEDIA_STOP			[IN_HTML_MEDIA]
// HTML Structure
'<!doctype'				NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'<base'					NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'<basefont'				NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'<body'					NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'</body'				NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'<head'					NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'</head'				NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'<html'					NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'</html'				NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'<link'					NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'<meta'					NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'<title'				NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'</title'				NOT_ALPHA			HTML_STRUCTURE_START	[IN_DEFAULT]
'>'						DONT_CARE			HTML_STRUCTURE_STOP		[IN_HTML_STRUCTURE]
// HTML Table
'<caption'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</caption'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<col'					NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<colgroup'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</colgroup'			NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<table'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</table'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<td'					NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</td'					NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<tbody'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</tbody'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<tfoot'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</tfoot'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<th'					NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</th'					NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<thead'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</thead'				NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'<tr'					NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'</tr'					NOT_ALPHA			HTML_TABLE_START		[IN_DEFAULT]
'>'						DONT_CARE			HTML_TABLE_STOP			[IN_HTML_TABLE]
// HTML Tags
'<'						ALPHA				HTML_TAG_START			[IN_DEFAULT]
'</'					DONT_CARE			HTML_TAG_START			[IN_DEFAULT]
'>'						DONT_CARE			HTML_TAG_STOP			[IN_HTML_TAG]
// HTML Whitespace
'<br'					NOT_ALPHA			HTML_WHITESPACE_START	[IN_DEFAULT]
'<hr'					NOT_ALPHA			HTML_WHITESPACE_START	[IN_DEFAULT]
'<nobr'					NOT_ALPHA			HTML_WHITESPACE_START	[IN_DEFAULT]
'</nobr'				NOT_ALPHA			HTML_WHITESPACE_START	[IN_DEFAULT]
'<spacer'				NOT_ALPHA			HTML_WHITESPACE_START	[IN_DEFAULT]
'<wbr'					NOT_ALPHA			HTML_WHITESPACE_START	[IN_DEFAULT]
'>'						DONT_CARE			HTML_WHITESPACE_STOP	[IN_HTML_WHITESPACE]

// HTML Special Characters
'&'						'[A-Za-z0-9#]'		HTML_SPECIAL			[IN_DEFAULT]

%%handlers
HTML_SPECIAL			'[A-Za-z0-9#]'?		';'						_use_

%%tokens
InState IN_HTML_BLOCK (
	HTML_BLOCK			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_COMMENT (
	HTML_COMMENT		DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_FORM (
	HTML_FORM			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_FORMAT (
	HTML_FORMAT			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_FRAME (
	HTML_FRAME			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_IMAGE (
	HTML_IMAGE			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_IMAGEMAP (
	HTML_IMAGEMAP		DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_LINK (
	HTML_LINK			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_LIST (
	HTML_LIST			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_MEDIA (
	HTML_MEDIA			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_STRUCTURE (
	HTML_STRUCTURE		DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_TABLE (
	HTML_TABLE			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_TAG (
	HTML_TAG			DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

InState IN_HTML_WHITESPACE (
	HTML_WHITESPACE		DONT_CARE			DONT_CARE?			DONT_CARE			_discard_
)

%%states
HTML_BLOCK_START		(-[IN_DEFAULT]						+[IN_HTML_BLOCK])
HTML_BLOCK_STOP			(-[IN_HTML_BLOCK]					+[IN_DEFAULT])

HTML_COMMENT_START		(-[IN_DEFAULT]						+[IN_HTML_COMMENT])
HTML_COMMENT_STOP		(-[IN_HTML_COMMENT]					+[IN_DEFAULT])

HTML_FORM_START			(-[IN_DEFAULT]						+[IN_HTML_FORM])
HTML_FORM_STOP			(-[IN_HTML_FORM]					+[IN_DEFAULT])

HTML_FORMAT_START		(-[IN_DEFAULT]						+[IN_HTML_FORMAT])
HTML_FORMAT_STOP		(-[IN_HTML_FORMAT]					+[IN_DEFAULT])

HTML_FRAME_START		(-[IN_DEFAULT]						+[IN_HTML_FRAME])
HTML_FRAME_STOP			(-[IN_HTML_FRAME]					+[IN_DEFAULT])

HTML_IMAGE_START		(-[IN_DEFAULT]						+[IN_HTML_IMAGE])
HTML_IMAGE_STOP			(-[IN_HTML_IMAGE]					+[IN_DEFAULT])

HTML_IMAGEMAP_START		(-[IN_DEFAULT]						+[IN_HTML_IMAGEMAP])
HTML_IMAGEMAP_STOP		(-[IN_HTML_IMAGEMAP]				+[IN_DEFAULT])

HTML_LINK_START			(-[IN_DEFAULT]						+[IN_HTML_LINK])
HTML_LINK_STOP			(-[IN_HTML_LINK]					+[IN_DEFAULT])

HTML_LIST_START			(-[IN_DEFAULT]						+[IN_HTML_LIST])
HTML_LIST_STOP			(-[IN_HTML_LIST]					+[IN_DEFAULT])

HTML_MEDIA_START		(-[IN_DEFAULT]						+[IN_HTML_MEDIA])
HTML_MEDIA_STOP			(-[IN_HTML_MEDIA]					+[IN_DEFAULT])

HTML_STRUCTURE_START	(-[IN_DEFAULT]						+[IN_HTML_STRUCTURE])
HTML_STRUCTURE_STOP		(-[IN_HTML_STRUCTURE]				+[IN_DEFAULT])

HTML_TABLE_START		(-[IN_DEFAULT]						+[IN_HTML_TABLE])
HTML_TABLE_STOP			(-[IN_HTML_TABLE]					+[IN_DEFAULT])

HTML_TAG_START			(-[IN_DEFAULT]						+[IN_HTML_TAG])
HTML_TAG_STOP			(-[IN_HTML_TAG]						+[IN_DEFAULT])

HTML_WHITESPACE_START	(-[IN_DEFAULT]						+[IN_HTML_WHITESPACE])
HTML_WHITESPACE_STOP	(-[IN_HTML_WHITESPACE]				+[IN_DEFAULT])

%%effects
HTML_BLOCK				[]					clNavy					DEFAULT_BACKGROUND*
HTML_COMMENT			[]					clGray					DEFAULT_BACKGROUND*
HTML_FORM				[]					clOrange				DEFAULT_BACKGROUND*
HTML_FORMAT				[]					clBlue					DEFAULT_BACKGROUND*
HTML_FRAME				[]					clSoftBlue				DEFAULT_BACKGROUND*
HTML_IMAGE				[]					clPurple				DEFAULT_BACKGROUND*
HTML_IMAGEMAP			[]					clPurple				DEFAULT_BACKGROUND*
HTML_LINK				[]					clGreen					DEFAULT_BACKGROUND*
HTML_LIST				[]					clNavy					DEFAULT_BACKGROUND*
HTML_MEDIA				[]					clOlive					DEFAULT_BACKGROUND*
HTML_SPECIAL			[fsBold]			DEFAULT_FOREGROUND*		DEFAULT_BACKGROUND*
HTML_STRUCTURE			[]					clNavy					DEFAULT_BACKGROUND*
HTML_TABLE				[]					clTeal					DEFAULT_BACKGROUND*
HTML_TAG				[]					clNavy					DEFAULT_BACKGROUND*
HTML_WHITESPACE			[]					clNavy					DEFAULT_BACKGROUND*

%%map
HTML_BLOCK				HTML_BLOCK
HTML_BLOCK_START		HTML_BLOCK
HTML_BLOCK_STOP			HTML_BLOCK
HTML_COMMENT			HTML_COMMENT
HTML_COMMENT_START		HTML_COMMENT
HTML_COMMENT_STOP		HTML_COMMENT
HTML_FORM				HTML_FORM
HTML_FORM_START			HTML_FORM
HTML_FORM_STOP			HTML_FORM
HTML_FORMAT				HTML_FORMAT
HTML_FORMAT_START		HTML_FORMAT
HTML_FORMAT_STOP		HTML_FORMAT
HTML_FRAME				HTML_FRAME
HTML_FRAME_START		HTML_FRAME
HTML_FRAME_STOP			HTML_FRAME
HTML_IMAGE				HTML_IMAGE
HTML_IMAGE_START		HTML_IMAGE
HTML_IMAGE_STOP			HTML_IMAGE
HTML_IMAGEMAP			HTML_IMAGEMAP
HTML_IMAGEMAP_START		HTML_IMAGEMAP
HTML_IMAGEMAP_STOP		HTML_IMAGEMAP
HTML_LINK				HTML_LINK
HTML_LINK_START			HTML_LINK
HTML_LINK_STOP			HTML_LINK
HTML_LIST				HTML_LIST
HTML_LIST_START			HTML_LIST
HTML_LIST_STOP			HTML_LIST
HTML_MEDIA				HTML_MEDIA
HTML_MEDIA_START		HTML_MEDIA
HTML_MEDIA_STOP			HTML_MEDIA
HTML_SPECIAL			HTML_SPECIAL
HTML_STRUCTURE			HTML_STRUCTURE
HTML_STRUCTURE_START	HTML_STRUCTURE
HTML_STRUCTURE_STOP		HTML_STRUCTURE
HTML_TABLE				HTML_TABLE
HTML_TABLE_START		HTML_TABLE
HTML_TABLE_STOP			HTML_TABLE
HTML_TAG				HTML_TAG
HTML_TAG_START			HTML_TAG
HTML_TAG_STOP			HTML_TAG
HTML_WHITESPACE			HTML_WHITESPACE
HTML_WHITESPACE_START	HTML_WHITESPACE
HTML_WHITESPACE_STOP	HTML_WHITESPACE

